@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <QApplication>
@@ -31,8 +20,7 @@ int main( int argc, char** argv ) {
     Widget widget;
     widget.resize( 600, 600 );
 
-    QVector< QPair <qreal, qreal> > vec0;
-    QVector< qreal > vec1,  vec2;
+    QVector< qreal > vec1;
 
     vec1 << 25 << 16 << 9 << 4 << 1 << 0
          << 1 << 4 << 9 << 16 << 25;
