@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "mainwindow.h"
@@ -73,6 +62,8 @@ MainWindow::MainWindow( QWidget* parent ) :
     m_chart->coordinatePlane()->setBackgroundAttributes(  pba );
 
     m_chart->setGlobalLeadingTop( 20 );
+
+    connect(reverse, SIGNAL(toggled(bool)), this, SLOT(setReverseDirection(bool)));
 }
 
 
@@ -216,7 +207,7 @@ void MainWindow::on_fixPlaneSizeCB_toggled( bool checked )
 {
     CartesianCoordinatePlane* plane =
         qobject_cast<CartesianCoordinatePlane*>( m_chart->coordinatePlane() );
-    if ( plane == 0 )
+    if ( plane == nullptr )
         return;
     plane->setFixedDataCoordinateSpaceRelation( checked );
     // just a little adjustment:
@@ -229,3 +220,17 @@ void MainWindow::on_fixPlaneSizeCB_toggled( bool checked )
     }
     m_chart->update();
 }
+
+void MainWindow::setReverseDirection(bool reverse)
+{
+    CartesianCoordinatePlane* plane =
+    qobject_cast<CartesianCoordinatePlane*>( m_chart->coordinatePlane() );
+    if ( plane == nullptr )
+        return;
+
+    if (axes->currentIndex() == 0) {
+        plane->setHorizontalRangeReversed(reverse);
+    } else if (axes->currentIndex() == 1) {
+        plane->setVerticalRangeReversed(reverse);
+    }
+}
