@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "mainwindow.h"
@@ -36,6 +25,7 @@
 #include <QPainter>
 #include <QFileDialog>
 #include <QPrinter>
+#include <QPrintPreviewDialog>
 
 using namespace KChart;
 
@@ -92,8 +82,8 @@ MainWindow::MainWindow( QWidget* parent ) :
 #ifdef USE_FRAME_WIDGET
     chartFrameWidget->setChart( m_chart );
     // make sure, we re-draw after changing one of the chart's properties
-    connect( m_chart,          SIGNAL( propertiesChanged() ),
-             chartFrameWidget, SLOT(   update() ) ) ;
+    connect( m_chart,          SIGNAL(propertiesChanged()),
+             chartFrameWidget, SLOT(update()) ) ;
 #else
     chartLayout->addWidget( m_chart );
 #endif
@@ -166,13 +156,27 @@ MainWindow::MainWindow( QWidget* parent ) :
     m_chart->setFrameAttributes( faChart );
 
     // initialize attributes; this is necessary because we need to enable data value attributes before
-    // any of them (e.g. only markers) can be displayed. but if we enable data value attributs, a default
+    // any of them (e.g. only markers) can be displayed. but if we enable data value attributes, a default
     // data value text is included, even if we only wanted to set markers. so we enable DVA and then
     // individually disable the parts we don't want.
     on_paintValuesCB_toggled( false );
     on_paintMarkersCB_toggled( false );
 }
 
+void MainWindow::slotPaintRequested(QPrinter *printer)
+{
+    QPainter painter(printer);
+    m_chart->paint(&painter, painter.window());
+}
+
+void MainWindow::on_printButton_clicked()
+{
+    static QPrinter printer;
+    QPrintPreviewDialog dialog(&printer);
+    connect(&dialog, SIGNAL(paintRequested(QPrinter*)), this, SLOT(slotPaintRequested(QPrinter*)));
+    dialog.exec();
+}
+
 void MainWindow::on_lineTypeCB_currentIndexChanged( const QString & text )
 {
     if ( text == "Normal" )
@@ -189,7 +193,7 @@ void MainWindow::on_lineTypeCB_currentIndexChanged( const QString & text )
 void MainWindow::on_paintLegendCB_toggled( bool checked )
 {
     KChart::Legend* legend = m_chart->legend();
-    if ( checked != ( legend != 0 ) ) {
+    if ( checked != ( legend != nullptr ) ) {
         if ( checked )
             m_chart->addLegend( m_legend );
         else
@@ -390,13 +394,15 @@ void MainWindow::on_savePDF_clicked()
         return;
     qDebug() << "Painting into PDF";
     QPrinter printer( QPrinter::HighResolution );
-    printer.setOrientation( QPrinter::Landscape );
+    printer.setPageOrientation( QPageLayout::Landscape );
     printer.setOutputFormat( QPrinter::PdfFormat );
     printer.setOutputFileName( file );
-    paintMarkers( paintMarkersCB->isChecked(), printer.pageRect().size() );
+    const auto resolution = printer.resolution();
+    const auto pageRect = printer.pageLayout().paintRectPixels(resolution);
+    paintMarkers( paintMarkersCB->isChecked(), pageRect.size() );
     QPainter painter;
     painter.begin( &printer );
-    m_chart->paint( &painter, printer.pageRect() );
+    m_chart->paint( &painter, pageRect );
     painter.end();
     paintMarkers( paintMarkersCB->isChecked(), m_chart->geometry().size() );
     qDebug() << "Painting into PDF - done";
