@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KGantt library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "mainwindow.h"
@@ -239,7 +228,7 @@ MainWindow::MainWindow( QWidget* parent )
     m_view->setConstraintModel(new KGantt::ConstraintModel(m_view));
     m_view->constraintModel()->addConstraint(KGantt::Constraint(m_model->index(0,0,QModelIndex()),m_model->index(1,0,QModelIndex())));
     m_view->constraintModel()->addConstraint(KGantt::Constraint(m_model->index(1,0,QModelIndex()),m_model->index(2,0,QModelIndex())));
-    // invalid contraint
+    // invalid constraint
     m_view->constraintModel()->addConstraint(KGantt::Constraint(m_model->index(2,0,QModelIndex()),m_model->index(3,0,QModelIndex())));
 
     // no info
@@ -452,7 +441,7 @@ void MainWindow::slotFileSavePdf()
         return;
     }
     QPrinter printer(QPrinter::HighResolution);
-    printer.setOrientation(QPrinter::Landscape);
+    printer.setPageOrientation(QPageLayout::Landscape);
     printer.setColorMode(QPrinter::Color);
     printer.setOutputFormat(QPrinter::PdfFormat);
     printer.setOutputFileName(m_file);
@@ -469,7 +458,7 @@ void MainWindow::slotFilePrint()
         return;
     }
     QPrinter printer(QPrinter::HighResolution);
-    printer.setOrientation(QPrinter::Landscape);
+    printer.setPageOrientation(QPageLayout::Landscape);
     printer.setColorMode(QPrinter::Color);
     printer.setFullPage(true); // Let ganttview handle margins
     QPrintDialog dialog(&printer, this);
@@ -487,7 +476,7 @@ void MainWindow::slotFilePrintPreview()
         return;
     }
     QPrinter printer(QPrinter::HighResolution);
-    printer.setOrientation(QPrinter::Landscape);
+    printer.setPageOrientation(QPageLayout::Landscape);
     printer.setColorMode(QPrinter::Color);
     printer.setPageMargins(m_margins, QPageLayout::Millimeter);
     printer.setFullPage(true); // Let ganttview handle margins
