@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KGantt library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef PRINTINGMAINWINDOW_H
@@ -32,6 +21,7 @@ class QRadioButton;
 class QPrinter;
 class QDateTimeEdit;
 class QLabel;
+class QDoubleSpinBox;
 
 namespace KGantt {
     class View;
@@ -55,6 +45,7 @@ public:
     QCheckBox *m_useEndTime;
     QDateTimeEdit *m_startTime;
     QDateTimeEdit *m_endTime;
+    QDoubleSpinBox *m_margin;
     
     SavePdfDialog(QWidget *parent = nullptr);
 private Q_SLOTS:
@@ -92,6 +83,7 @@ private:
     QDateTime m_startTime;
     QDateTime m_endTime;
     QString m_file;
+    QMarginsF m_margins;
 };
 #endif /* PRINTINGMAINWINDOW_H */
 
