@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "mainwindow.h"
@@ -194,11 +183,7 @@ void MainWindow::openFile(const QString &path)
 
                     m_model->insertRows(row, 1, QModelIndex());
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                    QStringList pieces = line.split( ',', QString::SkipEmptyParts );
-#else
                     QStringList pieces = line.split( ',', Qt::SkipEmptyParts );
-#endif
                     m_model->setData( m_model->index( row, 0, QModelIndex() ),
                                       pieces.value( 0 ) );
                     m_model->setData( m_model->index(row, 1, QModelIndex() ),
