@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <QStandardItemModel>
@@ -45,24 +34,30 @@ int main(int argc, char *argv[]) {
         qreal v = qreal(i)*i;
         QModelIndex index = model.index( i, 0 );
         model.setData( index, QVariant( t ) );
+        model.setData( index, QVariant( t ), Qt::ToolTipRole );
         index = model.index( i, 1 );
         model.setData( index, QVariant( v ) );
+        model.setData( index, QVariant( v ), Qt::ToolTipRole );
 
         // dateset 2
         t = i*2;
         v = qreal(i)*i-i;
         index = model.index( i, 2 );
         model.setData( index, QVariant( t ) );
+        model.setData( index, QVariant( t ), Qt::ToolTipRole );
         index = model.index( i, 3 );
         model.setData( index, QVariant( v ) );
+        model.setData( index, QVariant( v ), Qt::ToolTipRole );
 
         // dateset 3
         t = qreal(i)/2;
         v = qreal(i)*i+i;
         index = model.index( i, 4 );
         model.setData( index, QVariant( t ) );
+        model.setData( index, QVariant( t ), Qt::ToolTipRole );
         index = model.index( i, 5 );
         model.setData( index, QVariant( v ) );
+        model.setData( index, QVariant( v ), Qt::ToolTipRole );
     }
 
     model.setHeaderData( 0, Qt::Horizontal, "Dataset 1" );
