@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "mainwindow.h"
@@ -66,7 +55,7 @@ static const DataType bubblesData[nBubbles] = {
 
 MainWindow::MainWindow( QWidget* parent ) :
     QWidget( parent ),
-    m_model(0)
+    m_model(nullptr)
 {
     setupUi( this );
 
@@ -92,7 +81,7 @@ MainWindow::MainWindow( QWidget* parent ) :
     m_plotter->addAxis( xAxis2 );
     m_plotter->addAxis( yAxis );
     m_plotter->addAxis( yAxis2 );
-    connect( threeDEnabled, SIGNAL( toggled(bool) ), this, SLOT( setMarkerAttributes() ) );
+    connect( threeDEnabled, SIGNAL(toggled(bool)), this, SLOT(setMarkerAttributes()) );
 
     m_chart->coordinatePlane()->replaceDiagram( m_plotter );
     m_chart->setGlobalLeading( 20, 20, 20, 20 );
