@@ -1,24 +1,12 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "mainwindow.h"
-#include <KChartChart>
 #include <KChartLegend>
 #include <KChartCartesianAxis>
 #include <QColorDialog>
@@ -60,7 +48,7 @@ MainWindow::MainWindow( QWidget *parent )
     m_diagram.addAxis( bottomAxis );
     m_diagram.addAxis( bottomAxis );
     applyColor( QColor( "chartreuse" ) );
-    const bool connected = connect( colorChooser, SIGNAL( clicked() ), SLOT( chooseColor() ) );
+    const bool connected = connect( colorChooser, SIGNAL(clicked()), SLOT(chooseColor()) );
     Q_ASSERT( connected );
     Q_UNUSED( connected );
 
