@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <QLabel>
@@ -31,9 +20,9 @@
 
 MainWindow::MainWindow( QWidget* parent )
     : QDialog( parent )
-    , m_chart( 0 )
-    , m_diagram( 0 )
-    , m_ternaryPlane( 0 )
+    , m_chart( nullptr )
+    , m_diagram( nullptr )
+    , m_ternaryPlane( nullptr )
 {
     setupUi( this );
     // make a chart
@@ -59,8 +48,8 @@ MainWindow::MainWindow( QWidget* parent )
 
     setupModel();
     m_diagram->setModel( &m_model );
-    connect( m_diagram, SIGNAL( clicked( QModelIndex ) ),
-             SLOT( indexClicked( QModelIndex ) ) );
+    connect( m_diagram, SIGNAL(clicked(QModelIndex)),
+             SLOT(indexClicked(QModelIndex)) );
 }
 
 void MainWindow::setupModel()
