@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "mainwindow.h"
@@ -57,7 +46,7 @@ class MainWindow::Private : public QObject
 public:
     int datasetCount() const;
     enum ChartType{ Bar, Line, Plotter, Polar, Pie };
-    Private( MainWindow *q = 0 );
+    Private( MainWindow *q = nullptr );
     Chart *m_chartWin;
     CartesianCoordinatePlane *m_cartPlane;
     TableModel *m_model;
@@ -98,7 +87,7 @@ MainWindow::Private::Private( MainWindow *q )
     QDockWidget *diagramTypeSettingsDock = new QDockWidget( tr( "DiagramType" ), qq );
     diagramTypeSettingsDock->setWidget( diagramTypeSettings );
     diagramTypeSettingsDock->setFloating( false );
-    connect( diagramTypeSettings, SIGNAL( diagramTypeChanged( DiagramType, Subtype ) ), this, SLOT( changedChartType() ) );
+    connect( diagramTypeSettings, SIGNAL(diagramTypeChanged(DiagramType,Subtype)), this, SLOT(changedChartType()) );
     q->addDockWidget( Qt::LeftDockWidgetArea, diagramTypeSettingsDock );
 
     AxisSettings *axisSettings = new AxisSettings( m_chartWin, qq );
@@ -106,15 +95,15 @@ MainWindow::Private::Private( MainWindow *q )
     axisSettingsDock->setWidget( axisSettings );
     axisSettingsDock->setFloating( false );
     q->addDockWidget( Qt::LeftDockWidgetArea, axisSettingsDock );
-    connect( diagramTypeSettings, SIGNAL( diagramTypeChanged( DiagramType, Subtype ) ), axisSettings, SLOT( diagramTypeChanged() ) );
+    connect( diagramTypeSettings, SIGNAL(diagramTypeChanged(DiagramType,Subtype)), axisSettings, SLOT(diagramTypeChanged()) );
 
     DatasetSettings *setSettings = new DatasetSettings( m_chartWin, qq );
     QDockWidget *setSettingsDock = new QDockWidget( tr( "DatasetSettings" ), qq );
     setSettingsDock->setWidget( setSettings );
     setSettingsDock->setFloating( false );
     q->addDockWidget( Qt::LeftDockWidgetArea, setSettingsDock );
-    connect( this, SIGNAL( datasetCountChanged( int ) ), setSettings, SLOT( setDatasetCount( int ) ) );
-    connect( diagramTypeSettings, SIGNAL( diagramTypeChanged( DiagramType, Subtype ) ), setSettings, SLOT( diagramTypeChanged() ) );
+    connect( this, SIGNAL(datasetCountChanged(int)), setSettings, SLOT(setDatasetCount(int)) );
+    connect( diagramTypeSettings, SIGNAL(diagramTypeChanged(DiagramType,Subtype)), setSettings, SLOT(diagramTypeChanged()) );
     setSettings->setDatasetCount( m_model->columnCount() );
 
     DiagramSettings *diagSettings = new DiagramSettings( m_chartWin, qq );
@@ -122,14 +111,14 @@ MainWindow::Private::Private( MainWindow *q )
     diagSettingsDock->setWidget( diagSettings );
     diagSettingsDock->setFloating( false );
     q->addDockWidget( Qt::LeftDockWidgetArea, diagSettingsDock );
-    connect( diagramTypeSettings, SIGNAL( diagramTypeChanged( DiagramType, Subtype ) ), diagSettings, SLOT( refreshSettings() ) );
+    connect( diagramTypeSettings, SIGNAL(diagramTypeChanged(DiagramType,Subtype)), diagSettings, SLOT(refreshSettings()) );
 
     DataValueSettings *dataValueSettings = new DataValueSettings( m_chartWin, qq );
     QDockWidget *dataValueSettingsDock = new QDockWidget( tr( "DataValueSettings" ), qq );
     dataValueSettingsDock->setWidget( dataValueSettings );
     dataValueSettingsDock->setFloating( false );
     q->addDockWidget( Qt::RightDockWidgetArea, dataValueSettingsDock );
-    connect( diagramTypeSettings, SIGNAL( diagramTypeChanged( DiagramType, Subtype ) ), dataValueSettings, SLOT( refresh() ) );
+    connect( diagramTypeSettings, SIGNAL(diagramTypeChanged(DiagramType,Subtype)), dataValueSettings, SLOT(refresh()) );
 
 }
 
