@@ -1,20 +1,9 @@
 /**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "framewidget.h"
@@ -26,9 +15,9 @@
 
 FrameWidget::FrameWidget( QWidget* parent, Qt::WindowFlags f )
     : QWidget( parent, f )
-    , mChart( 0 )
+    , mChart( nullptr )
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 void FrameWidget::setChart( KChart::Chart* chart )
@@ -36,7 +25,7 @@ void FrameWidget::setChart( KChart::Chart* chart )
     mChart = chart;
     // This is necessary because Chart can't automatically schedule somebody else (this object) to
     // call its custom paint method.
-    connect( mChart, SIGNAL( propertiesChanged() ), SLOT( update() ) );
+    connect( mChart, SIGNAL(propertiesChanged()), SLOT(update()) );
 }
 
 void FrameWidget::paintEvent( QPaintEvent* e )
