@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartNormalPlotter_p.h"
@@ -93,7 +82,7 @@ void NormalPlotter::paint( PaintContext* ctx )
 
                     // data point label
                     const PositionPoints pts = PositionPoints( b, a, d, c );
-                    m_private->addLabel( &lpc, sourceIndex, 0, pts, Position::NorthWest,
+                    m_private->addLabel( &lpc, sourceIndex, nullptr, pts, Position::NorthWest,
                                          Position::NorthWest, point.value );
 
                     const bool lineValid = a.toPoint() != b.toPoint() && PaintingHelpers::isFinite( a );
@@ -161,7 +150,7 @@ void NormalPlotter::paint( PaintContext* ctx )
 
                     // data point label
                     const PositionPoints pts = PositionPoints( b, a, d, c );
-                    m_private->addLabel( &lpc, sourceIndex, 0, pts, Position::NorthWest,
+                    m_private->addLabel( &lpc, sourceIndex, nullptr, pts, Position::NorthWest,
                                          Position::NorthWest, point.value );
 
                     const bool lineValid = a.toPoint() != b.toPoint() && PaintingHelpers::isFinite( a );
