@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartBarDiagram.h"
@@ -106,8 +95,8 @@ void BarDiagram::Private::setOrientationAndType( Qt::Orientation o, BarDiagram::
     // AbstractAxis settings - see AbstractDiagram and CartesianAxis
     barDia->setPercentMode( type == BarDiagram::Percent );
     barDia->setDataBoundariesDirty();
-    emit barDia->layoutChanged( barDia );
-    emit barDia->propertiesChanged();
+    Q_EMIT barDia->layoutChanged( barDia );
+    Q_EMIT barDia->propertiesChanged();
 }
 
 #define d d_func()
@@ -179,13 +168,13 @@ Qt::Orientation BarDiagram::orientation() const
 void BarDiagram::setBarAttributes( const BarAttributes& ba )
 {
     d->attributesModel->setModelData( QVariant::fromValue( ba ), BarAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void BarDiagram::setBarAttributes( int column, const BarAttributes& ba )
 {
     d->setDatasetAttrs( column, QVariant::fromValue( ba ), BarAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void BarDiagram::setBarAttributes( const QModelIndex& index, const BarAttributes& ba )
@@ -194,7 +183,7 @@ void BarDiagram::setBarAttributes( const QModelIndex& index, const BarAttributes
         d->attributesModel->mapFromSource( index ),
         QVariant::fromValue( ba ),
         BarAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 BarAttributes BarDiagram::barAttributes() const
@@ -221,16 +210,16 @@ void BarDiagram::setThreeDBarAttributes( const ThreeDBarAttributes& threeDAttrs
 {
     setDataBoundariesDirty();
     d->attributesModel->setModelData( QVariant::fromValue( threeDAttrs ), ThreeDBarAttributesRole );
-    emit layoutChanged( this );
-    emit propertiesChanged();
+    Q_EMIT layoutChanged( this );
+    Q_EMIT propertiesChanged();
 }
 
 void BarDiagram::setThreeDBarAttributes( int column, const ThreeDBarAttributes& threeDAttrs )
 {
     setDataBoundariesDirty();
     d->setDatasetAttrs( column,  QVariant::fromValue( threeDAttrs ), ThreeDBarAttributesRole );
-    //emit layoutChanged( this );
-    emit propertiesChanged();
+    //Q_EMIT layoutChanged( this );
+    Q_EMIT propertiesChanged();
 }
 
 void BarDiagram::setThreeDBarAttributes( const QModelIndex& index, const ThreeDBarAttributes& threeDAttrs )
@@ -240,8 +229,8 @@ void BarDiagram::setThreeDBarAttributes( const QModelIndex& index, const ThreeDB
         d->attributesModel->mapFromSource(index),
         QVariant::fromValue( threeDAttrs ),
         ThreeDBarAttributesRole );
-    //emit layoutChanged( this );
-    emit propertiesChanged();
+    //Q_EMIT layoutChanged( this );
+    Q_EMIT propertiesChanged();
 }
 
 ThreeDBarAttributes BarDiagram::threeDBarAttributes() const
