@@ -1,23 +1,11 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#include "KChartBarDiagram.h"
 #include "KChartBarDiagram_p.h"
 
 #include "KChartDataValueAttributes.h"
@@ -78,7 +66,7 @@ void BarDiagram::BarDiagramType::paintBars( PaintContext* ctx, const QModelIndex
             bool drawIt = false;
             bool hasPointOutside = false;
             const QRectF r( ctx->rectangle().adjusted( 0, -1, 1, 0 ) );
-            Q_FOREACH( QPointF pt, topPoints ) {
+            for ( QPointF pt : qAsConst(topPoints) ) {
                 if ( r.contains( pt ) ) {
                     drawIt = true;
                 } else {
