@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartCartesianAxis.h"
@@ -147,15 +136,17 @@ TickIterator::TickIterator( CartesianAxis* a, CartesianCoordinatePlane* plane, u
 static QMap< qreal, QString > allAxisAnnotations( const AbstractCoordinatePlane *plane, bool isY )
 {
     QMap< qreal, QString > annotations;
-    Q_FOREACH( const AbstractDiagram *diagram, plane->diagrams() ) {
+    const auto diagrams = plane->diagrams();
+    for ( const AbstractDiagram* diagram : diagrams ) {
         const AbstractCartesianDiagram *cd = qobject_cast< const AbstractCartesianDiagram* >( diagram );
         if ( !cd ) {
             continue;
         }
-        Q_FOREACH( const CartesianAxis *axis, cd->axes() ) {
+        const auto axes = cd->axes();
+        for ( const CartesianAxis* axis : axes ) {
             const CartesianAxis::Private *axisPriv = CartesianAxis::Private::get( axis );
             if ( axisPriv->isVertical() == isY ) {
-                annotations.unite( axisPriv->annotations );
+                annotations.insert( axisPriv->annotations );
             }
         }
     }
@@ -405,7 +396,7 @@ void CartesianAxis::init()
     d->customTickLength = 3;
     d->position = Bottom;
     setCachedSizeDirty();
-    connect( this, SIGNAL(coordinateSystemChanged()), SLOT(coordinateSystemChanged()) );
+    connect( this, SIGNAL(coordinateSystemChanged()), SLOT(slotCoordinateSystemChanged()) );
 }
 
 
@@ -422,7 +413,7 @@ bool CartesianAxis::compare( const CartesianAxis* other ) const
             ( titleTextAttributes() == other->titleTextAttributes() );
 }
 
-void CartesianAxis::coordinateSystemChanged()
+void CartesianAxis::slotCoordinateSystemChanged()
 {
     layoutPlanes();
 }
