@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartCartesianCoordinatePlane.h"
@@ -66,17 +55,17 @@ CartesianCoordinatePlane::Private::Private()
 CartesianCoordinatePlane::CartesianCoordinatePlane( Chart* parent )
     : AbstractCoordinatePlane( new Private(), parent )
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 CartesianCoordinatePlane::~CartesianCoordinatePlane()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 void CartesianCoordinatePlane::init()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 
@@ -86,10 +75,10 @@ void CartesianCoordinatePlane::addDiagram( AbstractDiagram* diagram )
                 "CartesianCoordinatePlane::addDiagram", "Only cartesian "
                 "diagrams can be added to a cartesian coordinate plane!" );
     AbstractCoordinatePlane::addDiagram( diagram );
-    connect( diagram,  SIGNAL(layoutChanged(AbstractDiagram*)),
-             SLOT(slotLayoutChanged(AbstractDiagram*)) );
+    connect( diagram,  &AbstractDiagram::layoutChanged,
+             this, &CartesianCoordinatePlane::slotLayoutChanged );
 
-    connect( diagram, SIGNAL(propertiesChanged()), this, SIGNAL(propertiesChanged()) );
+    connect( diagram, &AbstractDiagram::propertiesChanged, this, &CartesianCoordinatePlane::propertiesChanged );
 }
 
 
@@ -157,7 +146,8 @@ QRectF CartesianCoordinatePlane::getRawDataBoundingRectFromDiagrams() const
     qreal minY = 0;
     qreal maxY = 0;
     bool bStarting = true;
-    Q_FOREACH( const AbstractDiagram* diagram, diagrams() )
+    const auto ds = diagrams();
+    for (const AbstractDiagram* diagram : ds)
     {
         QPair<QPointF, QPointF> dataBoundariesPair = diagram->dataBoundaries();
         //qDebug() << "CartesianCoordinatePlane::getRawDataBoundingRectFromDiagrams()\ngets diagram->dataBoundaries: " << dataBoundariesPair.first << dataBoundariesPair.second;
@@ -445,7 +435,7 @@ void CartesianCoordinatePlane::handleFixedDataCoordinateSpaceRelation( const QRe
         if ( doneSetZoomCenter( newCenter ) )
             changed = true;
         if ( changed )
-            emit propertiesChanged();
+            Q_EMIT propertiesChanged();
     }
 }
 
@@ -468,7 +458,7 @@ void CartesianCoordinatePlane::setIsometricScaling( bool isOn )
     if ( d->isometricScaling != isOn ) {
         d->isometricScaling = isOn;
         layoutDiagrams();
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
     }
 }
 
@@ -517,7 +507,7 @@ void CartesianCoordinatePlane::setZoomFactors( qreal factorX, qreal factorY )
 {
     if ( doneSetZoomFactorX( factorX ) || doneSetZoomFactorY( factorY ) ) {
         d->coordinateTransformation.updateTransform( logicalArea(), drawingArea() );
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
     }
 }
 
@@ -525,7 +515,7 @@ void CartesianCoordinatePlane::setZoomFactorX( qreal factor )
 {
     if ( doneSetZoomFactorX( factor ) ) {
         d->coordinateTransformation.updateTransform( logicalArea(), drawingArea() );
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
     }
 }
 
@@ -533,7 +523,7 @@ void CartesianCoordinatePlane::setZoomFactorY( qreal factor )
 {
     if ( doneSetZoomFactorY( factor ) ) {
         d->coordinateTransformation.updateTransform( logicalArea(), drawingArea() );
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
     }
 }
 
@@ -541,7 +531,7 @@ void CartesianCoordinatePlane::setZoomCenter( const QPointF& point )
 {
     if ( doneSetZoomCenter( point ) ) {
         d->coordinateTransformation.updateTransform( logicalArea(), drawingArea() );
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
     }
 }
 
@@ -577,10 +567,11 @@ void CartesianCoordinatePlane::setAxesCalcModes( AxesCalcMode mode )
         d->coordinateTransformation.axesCalcModeX != mode ) {
         d->coordinateTransformation.axesCalcModeY = mode;
         d->coordinateTransformation.axesCalcModeX = mode;
-        emit propertiesChanged();
-        emit viewportCoordinateSystemChanged();
-        Q_FOREACH( AbstractDiagram* diag, diagrams() )
-        slotLayoutChanged( diag );
+        Q_EMIT propertiesChanged();
+        Q_EMIT viewportCoordinateSystemChanged();
+        const auto ds = diagrams();
+        for (AbstractDiagram* diag : ds)
+            slotLayoutChanged( diag );
     }
 }
 
@@ -588,9 +579,9 @@ void CartesianCoordinatePlane::setAxesCalcModeY( AxesCalcMode mode )
 {
     if ( d->coordinateTransformation.axesCalcModeY != mode ) {
         d->coordinateTransformation.axesCalcModeY = mode;
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
         setGridNeedsRecalculate();
-        emit viewportCoordinateSystemChanged();
+        Q_EMIT viewportCoordinateSystemChanged();
     }
 }
 
@@ -598,8 +589,8 @@ void CartesianCoordinatePlane::setAxesCalcModeX( AxesCalcMode mode )
 {
     if ( d->coordinateTransformation.axesCalcModeX != mode ) {
         d->coordinateTransformation.axesCalcModeX = mode;
-        emit propertiesChanged();
-        emit viewportCoordinateSystemChanged();
+        Q_EMIT propertiesChanged();
+        Q_EMIT viewportCoordinateSystemChanged();
     }
 }
 
@@ -621,8 +612,8 @@ void CartesianCoordinatePlane::setHorizontalRange( const QPair< qreal, qreal > &
         d->horizontalMin = range.first;
         d->horizontalMax = range.second;
         layoutDiagrams();
-        emit propertiesChanged();
-        emit boundariesChanged();
+        Q_EMIT propertiesChanged();
+        Q_EMIT boundariesChanged();
     }
 }
 
@@ -633,8 +624,8 @@ void CartesianCoordinatePlane::setVerticalRange( const QPair< qreal, qreal > & r
         d->verticalMin = range.first;
         d->verticalMax = range.second;
         layoutDiagrams();
-        emit propertiesChanged();
-        emit boundariesChanged();
+        Q_EMIT propertiesChanged();
+        Q_EMIT boundariesChanged();
     }
 }
 
@@ -656,7 +647,7 @@ void CartesianCoordinatePlane::adjustRangesToData()
     d->verticalMin = dataBoundingRect.top();
     d->verticalMax = dataBoundingRect.bottom();
     layoutDiagrams();
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void CartesianCoordinatePlane::adjustHorizontalRangeToData()
@@ -665,7 +656,7 @@ void CartesianCoordinatePlane::adjustHorizontalRangeToData()
     d->horizontalMin = dataBoundingRect.left();
     d->horizontalMax = dataBoundingRect.right();
     layoutDiagrams();
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void CartesianCoordinatePlane::adjustVerticalRangeToData()
@@ -674,7 +665,7 @@ void CartesianCoordinatePlane::adjustVerticalRangeToData()
     d->verticalMin = dataBoundingRect.bottom();
     d->verticalMax = dataBoundingRect.top();
     layoutDiagrams();
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void CartesianCoordinatePlane::setAutoAdjustHorizontalRangeToData( unsigned int percentEmpty )
@@ -685,7 +676,7 @@ void CartesianCoordinatePlane::setAutoAdjustHorizontalRangeToData( unsigned int
         d->horizontalMin = 0.0;
         d->horizontalMax = 0.0;
         layoutDiagrams();
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
     }
 }
 
@@ -697,7 +688,7 @@ void CartesianCoordinatePlane::setAutoAdjustVerticalRangeToData( unsigned int pe
         d->verticalMin = 0.0;
         d->verticalMax = 0.0;
         layoutDiagrams();
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
     }
 }
 
@@ -721,7 +712,7 @@ void CartesianCoordinatePlane::setGridAttributes(
         d->gridAttributesVertical = a;
     setHasOwnGridAttributes( orientation, true );
     update();
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void CartesianCoordinatePlane::resetGridAttributes( Qt::Orientation orientation )
@@ -748,7 +739,7 @@ void CartesianCoordinatePlane::setHasOwnGridAttributes( Qt::Orientation orientat
         d->hasOwnGridAttributesHorizontal = on;
     else
         d->hasOwnGridAttributesVertical = on;
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 bool CartesianCoordinatePlane::hasOwnGridAttributes( Qt::Orientation orientation ) const
@@ -762,7 +753,7 @@ void CartesianCoordinatePlane::setAutoAdjustGridToZoom( bool autoAdjust )
     if ( d->autoAdjustGridToZoom != autoAdjust ) {
         d->autoAdjustGridToZoom = autoAdjust;
         d->grid->setNeedRecalculate();
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
     }
 }
 
@@ -782,7 +773,7 @@ AbstractCoordinatePlane* CartesianCoordinatePlane::sharedAxisMasterPlane( QPaint
     if ( diag != nullptr )
     {
         const CartesianAxisList axes = diag->axes();
-        Q_FOREACH( const CartesianAxis* a, axes )
+        for ( const CartesianAxis* a : axes )
         {
             CartesianCoordinatePlane* p = const_cast< CartesianCoordinatePlane* >(
                                               dynamic_cast< const CartesianCoordinatePlane* >( a->coordinatePlane() ) );
@@ -828,7 +819,7 @@ void CartesianCoordinatePlane::setHorizontalRangeReversed( bool reverse )
 
     d->reverseHorizontalPlane = reverse;
     layoutDiagrams();
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 bool CartesianCoordinatePlane::isHorizontalRangeReversed() const
@@ -843,7 +834,7 @@ void CartesianCoordinatePlane::setVerticalRangeReversed( bool reverse )
 
     d->reverseVerticalPlane = reverse;
     layoutDiagrams();
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 bool CartesianCoordinatePlane::isVerticalRangeReversed() const
@@ -884,7 +875,8 @@ void CartesianCoordinatePlane::setGeometry( const QRect& rectangle )
 
     AbstractCoordinatePlane::setGeometry( d->geometry );
 
-    Q_FOREACH( AbstractDiagram* diagram, diagrams() ) {
+    const auto ds = diagrams();
+    for (AbstractDiagram* diagram : ds) {
         diagram->resize( d->geometry.size() );
     }
 }
