@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartCartesianDiagramDataCompressor_p.h"
@@ -66,7 +55,8 @@ CartesianDiagramDataCompressor::AggregatedDataValueAttributes CartesianDiagramDa
 
     // aggregate attributes from all indices in the same CachePosition as index
     CartesianDiagramDataCompressor::AggregatedDataValueAttributes aggregated;
-    Q_FOREACH( const QModelIndex& neighborIndex, mapToModel( position ) ) {
+    const auto neighborIndexes = mapToModel( position );
+    for ( const QModelIndex& neighborIndex : neighborIndexes ) {
         DataValueAttributes attrs = diagram->dataValueAttributes( neighborIndex );
         // only store visible and unique attributes
         if ( !attrs.isVisible() ) {
@@ -498,7 +488,7 @@ void CartesianDiagramDataCompressor::retrieveModelData( const CachePosition& pos
             }
             result.value = std::numeric_limits< qreal >::quiet_NaN();
             result.key = 0.0;
-            Q_FOREACH( const QModelIndex& index, indexes ) {
+            for ( const QModelIndex& index : indexes ) {
                 const qreal value = m_modelCache.data( index );
                 if ( !ISNAN( value ) ) {
                     result.value = ISNAN( result.value ) ? value : result.value + value;
@@ -510,7 +500,7 @@ void CartesianDiagramDataCompressor::retrieveModelData( const CachePosition& pos
             result.value /= indexes.size();
         }
 
-        Q_FOREACH( const QModelIndex& index, indexes ) {
+        for ( const QModelIndex& index : indexes ) {
             // the DataPoint point is visible if any of the underlying, aggregated points is visible
             if ( m_model->data( index, DataHiddenRole ).value<bool>() == false ) {
                 result.hidden = false;
