@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KCHARTCARTESIANGRID_H
@@ -35,14 +24,14 @@ namespace KChart {
      *
      * The CartesianGrid interface is used
      * for calculating and for drawing
-     * the horizonal grid lines, and the vertical grid lines
+     * the horizontal grid lines, and the vertical grid lines
      * of a cartesian coordinate plane.
      */
     class CartesianGrid : public AbstractGrid
     {
     public:
         CartesianGrid();
-        virtual ~CartesianGrid();
+        ~CartesianGrid() override;
 
         int minimalSteps() const;
         void setMinimalSteps(int minsteps);
@@ -50,14 +39,14 @@ namespace KChart {
         int maximalSteps() const;
         void setMaximalSteps(int maxsteps);
 
-        void drawGrid( PaintContext* context ) Q_DECL_OVERRIDE;
+        void drawGrid( PaintContext* context ) override;
 
     private:
         int m_minsteps;
         int m_maxsteps;
         
         DataDimensionsList calculateGrid(
-            const DataDimensionsList& rawDataDimensions ) const Q_DECL_OVERRIDE;
+            const DataDimensionsList& rawDataDimensions ) const override;
 
         /**
          * Helper function called by calculateGrid() to calculate the grid of one dimension.
