@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartPlotter.h"
@@ -66,10 +55,10 @@ void Plotter::init()
     connect( this, SIGNAL(boundariesChanged()), test, SLOT(changedProperties()) );
     // The signal is connected to the superclass's slot at this point because the connection happened
     // in its constructor when "its type was not Plotter yet".
-    disconnect( this, SIGNAL(attributesModelAboutToChange(AttributesModel*,AttributesModel*)),
-                this, SLOT(connectAttributesModel(AttributesModel*)) );
-    connect( this, SIGNAL(attributesModelAboutToChange(AttributesModel*,AttributesModel*)),
-             this, SLOT(connectAttributesModel(AttributesModel*)) );
+    disconnect( this, SIGNAL(attributesModelAboutToChange(KChart::AttributesModel*,KChart::AttributesModel*)),
+                this, SLOT(connectAttributesModel(KChart::AttributesModel*)) );
+    connect( this, SIGNAL(attributesModelAboutToChange(KChart::AttributesModel*,KChart::AttributesModel*)),
+             this, SLOT(connectAttributesModel(KChart::AttributesModel*)) );
     setDatasetDimensionInternal( 2 );
 }
 
@@ -202,8 +191,8 @@ void Plotter::setType( const PlotType type )
     Q_ASSERT( d->implementor->type() == type );
 
     setDataBoundariesDirty();
-    emit layoutChanged( this );
-    emit propertiesChanged();
+    Q_EMIT layoutChanged( this );
+    Q_EMIT propertiesChanged();
 }
 
 Plotter::PlotType Plotter::type() const
@@ -214,33 +203,33 @@ Plotter::PlotType Plotter::type() const
 void Plotter::setLineAttributes( const LineAttributes& la )
 {
     d->attributesModel->setModelData( QVariant::fromValue( la ), LineAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void Plotter::setLineAttributes( int column, const LineAttributes& la )
 {
     d->setDatasetAttrs( column, QVariant::fromValue( la ), LineAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void Plotter::resetLineAttributes( int column )
 {
     d->resetDatasetAttrs( column, LineAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void Plotter::setLineAttributes( const QModelIndex & index, const LineAttributes& la )
 {
     d->attributesModel->setData( d->attributesModel->mapFromSource( index ),
                                  QVariant::fromValue( la ), LineAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void Plotter::resetLineAttributes( const QModelIndex & index )
 {
     d->attributesModel->resetData(
             d->attributesModel->mapFromSource(index), LineAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 LineAttributes Plotter::lineAttributes() const
@@ -266,14 +255,14 @@ void Plotter::setThreeDLineAttributes( const ThreeDLineAttributes& la )
 {
     setDataBoundariesDirty();
     d->attributesModel->setModelData( QVariant::fromValue( la ), ThreeDLineAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void Plotter::setThreeDLineAttributes( int column, const ThreeDLineAttributes& la )
 {
     setDataBoundariesDirty();
     d->setDatasetAttrs( column, QVariant::fromValue( la ), ThreeDLineAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void Plotter::setThreeDLineAttributes( const QModelIndex& index, const ThreeDLineAttributes& la )
@@ -281,7 +270,7 @@ void Plotter::setThreeDLineAttributes( const QModelIndex& index, const ThreeDLin
     setDataBoundariesDirty();
     d->attributesModel->setData( d->attributesModel->mapFromSource( index ), QVariant::fromValue( la ),
                                  ThreeDLineAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 ThreeDLineAttributes Plotter::threeDLineAttributes() const
@@ -318,7 +307,7 @@ void Plotter::setValueTrackerAttributes( const QModelIndex & index, const ValueT
 {
     d->attributesModel->setData( d->attributesModel->mapFromSource( index ),
                                  QVariant::fromValue( va ), KChart::ValueTrackerAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 ValueTrackerAttributes Plotter::valueTrackerAttributes( const QModelIndex & index ) const
