@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KCHARTABSTRACTAREA_H
@@ -51,7 +40,7 @@ class KCHART_EXPORT AbstractArea : public QObject,
     KCHART_DECLARE_PRIVATE_DERIVED( AbstractArea )
 
 public:
-    virtual ~AbstractArea() ;
+    ~AbstractArea()  override;
 
     /**
       * @brief Draws the background and frame, then calls paint().
@@ -65,7 +54,7 @@ public:
       * Call paintAll, if you want the background and the frame to be drawn
       * before the normal paint() is invoked automatically.
       */
-    void paintAll( QPainter& painter ) Q_DECL_OVERRIDE;
+    void paintAll( QPainter& painter ) override;
 
     /**
      * This is called at layout time by KChart::AutoSpacerLayoutItem::sizeHint().
@@ -122,11 +111,11 @@ public:
 
 protected:
     AbstractArea();
-    QRect areaGeometry() const Q_DECL_OVERRIDE;
-    void positionHasChanged() Q_DECL_OVERRIDE;
+    QRect areaGeometry() const override;
+    void positionHasChanged() override;
 
 Q_SIGNALS:
-    void positionChanged( AbstractArea * );
+    void positionChanged( KChart::AbstractArea * );
 }; // End of class AbstractArea
 
 }
