@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartAbstractAreaWidget.h"
@@ -131,7 +120,7 @@ void AbstractAreaWidget::paintIntoRect( QPainter& painter, const QRect& rect )
 
 void AbstractAreaWidget::forceRebuild()
 {
-    //bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 void AbstractAreaWidget::paintAll( QPainter& painter )
@@ -180,5 +169,5 @@ QRect AbstractAreaWidget::areaGeometry() const
 
 void AbstractAreaWidget::positionHasChanged()
 {
-    emit positionChanged( this );
+    Q_EMIT positionChanged( this );
 }
