@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartAbstractCoordinatePlane.h"
@@ -41,7 +30,7 @@ AbstractCoordinatePlane::Private::Private()
     , enableRubberBandZooming( false )
     , rubberBand( nullptr )
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 
@@ -143,7 +132,7 @@ ConstAbstractDiagramList AbstractCoordinatePlane::diagrams() const
 #ifndef QT_NO_STL
     qCopy( d->diagrams.begin(), d->diagrams.end(), std::back_inserter( list ) );
 #else
-    Q_FOREACH( AbstractDiagram * a, d->diagrams )
+    for ( AbstractDiagram * a : d->diagrams )
         list.push_back( a );
 #endif
     return list;
@@ -326,7 +315,7 @@ void KChart::AbstractCoordinatePlane::mousePressEvent( QMouseEvent* event )
         }
     }
 
-    Q_FOREACH( AbstractDiagram * a, d->diagrams )
+    for ( AbstractDiagram * a : qAsConst(d->diagrams) )
     {
         a->mousePressEvent( event );
     }
@@ -336,11 +325,11 @@ void KChart::AbstractCoordinatePlane::mouseDoubleClickEvent( QMouseEvent* event
 {
     if ( event->button() == Qt::RightButton )
     {
-        // othewise the second click gets lost
+        // otherwise the second click gets lost
         // which is pretty annoying when zooming out fast
         mousePressEvent( event );
     }
-    Q_FOREACH( AbstractDiagram * a, d->diagrams )
+    for ( AbstractDiagram * a : qAsConst(d->diagrams) )
     {
         a->mouseDoubleClickEvent( event );
     }
@@ -393,7 +382,7 @@ void KChart::AbstractCoordinatePlane::mouseReleaseEvent( QMouseEvent* event )
         event->accept();
     }
 
-    Q_FOREACH( AbstractDiagram * a, d->diagrams )
+    for ( AbstractDiagram * a : qAsConst(d->diagrams) )
     {
         a->mouseReleaseEvent( event );
     }
@@ -409,7 +398,7 @@ void KChart::AbstractCoordinatePlane::mouseMoveEvent( QMouseEvent* event )
         event->accept();
     }
 
-    Q_FOREACH( AbstractDiagram * a, d->diagrams )
+    for ( AbstractDiagram * a : qAsConst(d->diagrams) )
     {
         a->mouseMoveEvent( event );
     }
@@ -430,7 +419,6 @@ AbstractCoordinatePlane* KChart::AbstractCoordinatePlane::sharedAxisMasterPlane(
 }
 
 #if !defined(QT_NO_DEBUG_STREAM)
-#include "KChartEnums.h"
 
 QDebug KChart::operator<<( QDebug stream, const DataDimension& r )
 {
