@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartAbstractDiagram.h"
@@ -32,7 +21,6 @@
 #include "KChartChart.h"
 #include "KChartDataValueAttributes.h"
 #include "KChartTextAttributes.h"
-#include "KChartMarkerAttributes.h"
 #include "KChartAbstractThreeDAttributes.h"
 #include "KChartThreeDLineAttributes.h"
 #include "KChartPainterSaver_p.h"
@@ -52,7 +40,7 @@ AbstractDiagram::AbstractDiagram ( QWidget* parent, AbstractCoordinatePlane* pla
 
 AbstractDiagram::~AbstractDiagram()
 {
-    emit aboutToBeDestroyed();
+    Q_EMIT aboutToBeDestroyed();
     delete _d;
 }
 
@@ -145,7 +133,7 @@ void AbstractDiagram::setModel( QAbstractItemModel * newModel )
 
     scheduleDelayedItemsLayout();
     setDataBoundariesDirty();
-    emit modelsChanged();
+    Q_EMIT modelsChanged();
 }
 
 void AbstractDiagram::setSelectionModel( QItemSelectionModel* newSelectionModel )
@@ -161,7 +149,7 @@ void AbstractDiagram::setSelectionModel( QItemSelectionModel* newSelectionModel
         connect( selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SIGNAL(modelsChanged()) );
         connect( selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SIGNAL(modelsChanged()) );
     }
-    emit modelsChanged();
+    Q_EMIT modelsChanged();
 }
 
 /* Sets an external AttributesModel on this diagram. By default, a diagram has it's
@@ -188,7 +176,7 @@ void AbstractDiagram::setAttributesModel( AttributesModel* amodel )
     d->setAttributesModel( amodel );
     scheduleDelayedItemsLayout();
     setDataBoundariesDirty();
-    emit modelsChanged();
+    Q_EMIT modelsChanged();
 }
 
 bool AbstractDiagram::usesExternalAttributesModel() const
@@ -260,19 +248,19 @@ void AbstractDiagram::setHidden( const QModelIndex & index, bool hidden )
         conditionallyMapFromSource( index ),
         QVariant::fromValue( hidden ),
         DataHiddenRole );
-    emit dataHidden();
+    Q_EMIT dataHidden();
 }
 
 void AbstractDiagram::setHidden( int dataset, bool hidden )
 {
     d->setDatasetAttrs( dataset, QVariant::fromValue( hidden ), DataHiddenRole );
-    emit dataHidden();
+    Q_EMIT dataHidden();
 }
 
 void AbstractDiagram::setHidden( bool hidden )
 {
     d->attributesModel->setModelData( QVariant::fromValue( hidden ), DataHiddenRole );
-    emit dataHidden();
+    Q_EMIT dataHidden();
 }
 
 bool AbstractDiagram::isHidden() const
@@ -305,14 +293,14 @@ void AbstractDiagram::setDataValueAttributes( const QModelIndex & index,
 {
     d->attributesModel->setData( conditionallyMapFromSource( index ), QVariant::fromValue( a ),
                                  DataValueLabelAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 
 void AbstractDiagram::setDataValueAttributes( int dataset, const DataValueAttributes & a )
 {
     d->setDatasetAttrs( dataset, QVariant::fromValue( a ), DataValueLabelAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 DataValueAttributes AbstractDiagram::dataValueAttributes() const
@@ -350,7 +338,7 @@ DataValueAttributes AbstractDiagram::dataValueAttributes( const QModelIndex & in
 void AbstractDiagram::setDataValueAttributes( const DataValueAttributes & a )
 {
     d->attributesModel->setModelData( QVariant::fromValue( a ), DataValueLabelAttributesRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void AbstractDiagram::setAllowOverlappingDataValueTexts( bool allow )
@@ -359,7 +347,7 @@ void AbstractDiagram::setAllowOverlappingDataValueTexts( bool allow )
     attrs.setShowOverlappingDataLabels( allow );
     setDataValueAttributes( attrs );
     d->allowOverlappingDataValueTexts = allow;
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 bool AbstractDiagram::allowOverlappingDataValueTexts() const
@@ -370,7 +358,7 @@ bool AbstractDiagram::allowOverlappingDataValueTexts() const
 void AbstractDiagram::setAntiAliasing( bool enabled )
 {
     d->antiAliasing = enabled;
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 bool AbstractDiagram::antiAliasing() const
@@ -381,7 +369,7 @@ bool AbstractDiagram::antiAliasing() const
 void AbstractDiagram::setPercentMode ( bool percent )
 {
     d->percent = percent;
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 bool AbstractDiagram::percentMode() const
@@ -444,8 +432,8 @@ void AbstractDiagram::paintMarker( QPainter* painter,
     switch( ma.markerSizeMode() ) {
     case MarkerAttributes::AbsoluteSize:
         // Unscaled, i.e. without the painter's "zoom"
-        maSize.rwidth()  /= painter->matrix().m11();
-        maSize.rheight() /= painter->matrix().m22();
+        maSize.rwidth()  /= painter->transform().m11();
+        maSize.rheight() /= painter->transform().m22();
         break;
     case MarkerAttributes::AbsoluteSizeScaled:
         // Keep maSize as is. It is specified directly in pixels and desired
@@ -468,7 +456,13 @@ void AbstractDiagram::paintMarker( QPainter* painter,
     // basically save a circle of radius maSize at pos in the
     // reverseMapper. This means that ^^^ this version of paintMarker
     // needs to be called to reverse-map the marker.
-    d->reverseMapper.addCircle( index.row(), index.column(), pos, 2 * maSize );
+    if ((ma.markerStyle() == MarkerAttributes::Marker4Pixels) || (ma.markerStyle() == MarkerAttributes::Marker1Pixel)) {
+        auto rect = QRectF({}, maSize);
+        rect.moveCenter(pos);
+        d->reverseMapper.addRect( index.row(), index.column(), rect );
+    } else {
+        d->reverseMapper.addCircle( index.row(), index.column(), pos, 2 * maSize );
+    }
 }
 
 void AbstractDiagram::paintMarker( QPainter* painter,
@@ -528,7 +522,7 @@ void AbstractDiagram::paintMarker( QPainter* painter,
                     grad.setColorAt( 0.95, drawColor.darker( 250 ) );
                     grad.setColorAt( 1.00, drawColor.darker( 200 ) );
                     QBrush newBrush( grad );
-                    newBrush.setMatrix( brush.matrix() );
+                    newBrush.setTransform( brush.transform() );
                     painter->setBrush( newBrush );
                 }
                 painter->drawEllipse( QRectF( 0 - maSize.height()/2, 0 - maSize.width()/2,
@@ -830,20 +824,20 @@ void AbstractDiagram::setPen( const QModelIndex& index, const QPen& pen )
     attributesModel()->setData(
         conditionallyMapFromSource( index ),
         QVariant::fromValue( pen ), DatasetPenRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void AbstractDiagram::setPen( const QPen& pen )
 {
     attributesModel()->setModelData(
         QVariant::fromValue( pen ), DatasetPenRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void AbstractDiagram::setPen( int dataset, const QPen& pen )
 {
     d->setDatasetAttrs( dataset, QVariant::fromValue( pen ), DatasetPenRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 QPen AbstractDiagram::pen() const
@@ -871,20 +865,20 @@ void AbstractDiagram::setBrush( const QModelIndex& index, const QBrush& brush )
     attributesModel()->setData(
         conditionallyMapFromSource( index ),
         QVariant::fromValue( brush ), DatasetBrushRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void AbstractDiagram::setBrush( const QBrush& brush )
 {
     attributesModel()->setModelData(
         QVariant::fromValue( brush ), DatasetBrushRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void AbstractDiagram::setBrush( int dataset, const QBrush& brush )
 {
     d->setDatasetAttrs( dataset, QVariant::fromValue( brush ), DatasetBrushRole );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 QBrush AbstractDiagram::brush() const
@@ -987,7 +981,7 @@ QString AbstractDiagram::unitSuffix( int column, Qt::Orientation orientation, bo
 
 /* Returns the global unit suffix
   * @param orientation the orientation of the axis
-  * @return the unit siffix
+  * @return the unit suffix
   */
 QString AbstractDiagram::unitSuffix( Qt::Orientation orientation ) const
 {
@@ -1021,7 +1015,7 @@ void AbstractDiagram::setSelection(const QRect& rect , QItemSelectionModel::Sele
 {
     const QModelIndexList indexes = d->indexesIn( rect );
     QItemSelection selection;
-    Q_FOREACH( const QModelIndex& index, indexes )
+    for ( const QModelIndex& index : indexes )
     {
         selection.append( QItemSelectionRange( index ) );
     }
@@ -1031,7 +1025,9 @@ void AbstractDiagram::setSelection(const QRect& rect , QItemSelectionModel::Sele
 QRegion AbstractDiagram::visualRegionForSelection(const QItemSelection &selection) const
 {
     QPolygonF polygon;
-    Q_FOREACH( const QModelIndex& index, selection.indexes() )
+    const auto indexes = selection.indexes();
+    polygon.reserve(indexes.count());
+    for ( const QModelIndex& index : indexes )
     {
         polygon << d->reverseMapper.polygon(index.row(), index.column());
     }
@@ -1160,7 +1156,7 @@ void AbstractDiagram::setDatasetDimensionInternal( int dimension )
     d->datasetDimension = dimension;
     d->attributesModel->setDatasetDimension( dimension );
     setDataBoundariesDirty();
-    emit layoutChanged( this );
+    Q_EMIT layoutChanged( this );
 }
 
 qreal AbstractDiagram::valueForCell( int row, int column ) const
