@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 //
@@ -130,7 +119,7 @@ void AbstractDiagram::Private::setAttributesModel( AttributesModel* amodel )
         }
     }
 
-    emit diagram->attributesModelAboutToChange( amodel, attributesModel );
+    Q_EMIT diagram->attributesModelAboutToChange( amodel, attributesModel );
 
     connect( amodel, SIGNAL(rowsInserted(QModelIndex,int,int)),
              diagram, SLOT(setDataBoundariesDirty()) );
@@ -393,7 +382,7 @@ void AbstractDiagram::Private::paintDataValueTextsAndMarkers(
     ctx->painter()->setClipping( false );
 
     if ( paintMarkers && !justCalculateRect ) {
-        Q_FOREACH ( const LabelPaintInfo& info, cache.paintReplay ) {
+        for ( const LabelPaintInfo& info : qAsConst(cache.paintReplay) ) {
             diagram->paintMarker( ctx->painter(), info.index, info.markerPos );
         }
     }
@@ -410,7 +399,7 @@ void AbstractDiagram::Private::paintDataValueTextsAndMarkers(
 
     forgetAlreadyPaintedDataValues();
 
-    Q_FOREACH ( const LabelPaintInfo& info, cache.paintReplay ) {
+    for ( const LabelPaintInfo& info : qAsConst(cache.paintReplay) ) {
         const QPointF pos = info.labelArea.elementAt( 0 );
         paintDataValueText( ctx->painter(), info.attrs, pos, info.isValuePositive,
                             info.value, justCalculateRect, cumulatedBoundingRect );
