@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KCHARTABSTRACTDIAGRAM_P_H
@@ -51,6 +40,7 @@
 #include <QPaintDevice>
 #include <QPainterPath>
 #include <QModelIndex>
+#include <QPainterPath>
 
 
 namespace KChart {
@@ -132,14 +122,14 @@ namespace KChart {
                                             const LabelPaintCache& cache,
                                             bool paintMarkers,
                                             bool justCalculateRect=false,
-                                            QRectF* cumulatedBoundingRect=0 );
+                                            QRectF* cumulatedBoundingRect = nullptr );
 
         void paintDataValueText( QPainter* painter,
                                  const QModelIndex& index,
                                  const QPointF& pos,
                                  qreal value,
                                  bool justCalculateRect=false,
-                                 QRectF* cumulatedBoundingRect=0 );
+                                 QRectF* cumulatedBoundingRect = nullptr );
 
         void paintDataValueText( QPainter* painter,
                                  const DataValueAttributes& attrs,
@@ -147,7 +137,7 @@ namespace KChart {
                                  bool valueIsPositive,
                                  const QString& text,
                                  bool justCalculateRect=false,
-                                 QRectF* cumulatedBoundingRect=0 );
+                                 QRectF* cumulatedBoundingRect = nullptr );
 
         inline int datasetCount() const
         {
