@@ -1,26 +1,14 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartAttributesModel.h"
 
 #include "KChartPalette.h"
-#include "KChartGlobal.h"
 #include "KChartMath_p.h"
 
 #include <QDebug>
@@ -690,7 +678,7 @@ void AttributesModel::setDefaultForRole( int role, const QVariant& value )
     if ( value.isValid() ) {
         d->defaultsMap.insert( role, value );
     } else {
-        // erase the possibily existing value to not let the map grow:
+        // erase the possibly existing value to not let the map grow:
         QMap<int, QVariant>::iterator it = d->defaultsMap.find( role );
         if ( it != d->defaultsMap.end() ) {
             d->defaultsMap.erase( it );
