@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartChart.h"
@@ -273,7 +262,7 @@ void Chart::Private::slotUnregisterDestroyedHeaderFooter( HeaderFooter* hf )
 void Chart::Private::slotUnregisterDestroyedPlane( AbstractCoordinatePlane* plane )
 {
     coordinatePlanes.removeAll( plane );
-    Q_FOREACH ( AbstractCoordinatePlane* p, coordinatePlanes ) {
+    for ( AbstractCoordinatePlane* p : qAsConst(coordinatePlanes) ) {
         if ( p->referenceCoordinatePlane() == plane) {
             p->setReferenceCoordinatePlane( nullptr );
         }
@@ -326,7 +315,7 @@ static QVector< LayoutGraphNode* > getPrioritySortedConnectedComponents( QVector
 {
     QVector< LayoutGraphNode* >connectedComponents;
     QHash< LayoutGraphNode*, VisitorState > visitedComponents;
-    Q_FOREACH ( LayoutGraphNode* node, nodeList )
+    for ( LayoutGraphNode* node : nodeList )
         visitedComponents[ node ] = Unknown;
     for ( int i = 0; i < nodeList.size(); ++i )
     {
@@ -381,7 +370,8 @@ void checkExistingAxes( LayoutGraphNode* node )
         AbstractCartesianDiagram *diag = qobject_cast< AbstractCartesianDiagram* >( node->diagramPlane->diagram() );
         if ( diag )
         {
-            Q_FOREACH( const CartesianAxis* axis, diag->axes() )
+            const CartesianAxisList axes = diag->axes();
+            for ( const CartesianAxis* axis : axes )
             {
                 switch ( axis->position() )
                 {
@@ -433,7 +423,7 @@ static CoordinatePlaneList findSharingAxisDiagrams( AbstractCoordinatePlane* pla
         return CoordinatePlaneList();
 
     QList< CartesianAxis* > axes;
-    Q_FOREACH( CartesianAxis* axis, diagram->axes() ) {
+    for ( CartesianAxis* axis : diagram->axes() ) {
         if ( ( type == Chart::Private::Ordinate &&
               ( axis->position() == CartesianAxis::Left || axis->position() == CartesianAxis::Right ) )
             ||
@@ -442,15 +432,15 @@ static CoordinatePlaneList findSharingAxisDiagrams( AbstractCoordinatePlane* pla
             axes.append( axis );
         }
     }
-    Q_FOREACH( AbstractCoordinatePlane *curPlane, list )
+    for( AbstractCoordinatePlane *curPlane : list )
     {
         AbstractCartesianDiagram* diagram =
                 qobject_cast< AbstractCartesianDiagram* > ( curPlane->diagram() );
         if ( !diagram )
             continue;
-        Q_FOREACH( CartesianAxis* curSearchedAxis, axes )
+        for ( CartesianAxis* curSearchedAxis : qAsConst(axes) )
         {
-            Q_FOREACH( CartesianAxis* curAxis, diagram->axes() )
+            for( CartesianAxis* curAxis : diagram->axes() )
             {
                 if ( curSearchedAxis == curAxis )
                 {
@@ -476,7 +466,7 @@ QVector< LayoutGraphNode* > Chart::Private::buildPlaneLayoutGraph()
     QHash< AbstractCoordinatePlane*, LayoutGraphNode* > planeNodeMapping;
     QVector< LayoutGraphNode* > allNodes;
     // create all nodes and a mapping between plane and nodes
-    Q_FOREACH( AbstractCoordinatePlane* curPlane, coordinatePlanes )
+    for ( AbstractCoordinatePlane* curPlane : qAsConst(coordinatePlanes) )
     {
         if ( curPlane->diagram() )
         {
@@ -488,7 +478,7 @@ QVector< LayoutGraphNode* > Chart::Private::buildPlaneLayoutGraph()
         }
     }
     // build the graph connections
-    Q_FOREACH( LayoutGraphNode* curNode, allNodes )
+    for ( LayoutGraphNode* curNode : qAsConst(allNodes) )
     {
         QVector< CartesianAxis* > sharedAxes;
         CoordinatePlaneList xSharedPlanes = findSharingAxisDiagrams( curNode->diagramPlane, coordinatePlanes, Abscissa, &sharedAxes );
@@ -576,27 +566,30 @@ QHash<AbstractCoordinatePlane*, PlaneInfo> Chart::Private::buildPlaneLayoutInfos
      * they will be laid out in relation to each other as suggested by the position
      * of the axis. If, for example Plane1 and Plane2 share an axis at position Left,
      * that will result in the layout: Axis Plane1 Plane 2, vertically. If Plane1
-     * also happens to be Plane2's referece plane, both planes are drawn over each
+     * also happens to be Plane2's reference plane, both planes are drawn over each
      * other. The reference plane concept allows two planes to share the same space
      * even if neither has any axis, and in case there are shared axis, it is used
      * to decided, whether the planes should be painted on top of each other or
      * laid out vertically or horizontally next to each other. */
     QHash<CartesianAxis*, AxisInfo> axisInfos;
     QHash<AbstractCoordinatePlane*, PlaneInfo> planeInfos;
-    Q_FOREACH(AbstractCoordinatePlane* plane, coordinatePlanes ) {
+    for (AbstractCoordinatePlane* plane : qAsConst(coordinatePlanes) ) {
         PlaneInfo p;
         // first check if we share space with another plane
         p.referencePlane = plane->referenceCoordinatePlane();
         planeInfos.insert( plane, p );
 
-        Q_FOREACH( AbstractDiagram* abstractDiagram, plane->diagrams() ) {
+
+        const auto diagrams = plane->diagrams();
+        for ( AbstractDiagram* abstractDiagram : diagrams ) {
             AbstractCartesianDiagram* diagram =
                     qobject_cast<AbstractCartesianDiagram*> ( abstractDiagram );
             if ( !diagram ) {
                 continue;
             }
 
-            Q_FOREACH( CartesianAxis* axis, diagram->axes() ) {
+            const CartesianAxisList axes = diagram->axes();
+            for ( CartesianAxis* axis : axes ) {
                 if ( !axisInfos.contains( axis ) ) {
                     /* If this is the first time we see this axis, add it, with the
                      * current plane. The first plane added to the chart that has
@@ -660,11 +653,11 @@ void Chart::Private::slotLayoutPlanes()
     if ( hadPlanesLayout )
         planesLayout->getContentsMargins(&left, &top, &right, &bottom);
 
-    Q_FOREACH( AbstractLayoutItem* plane, planeLayoutItems ) {
+    for ( AbstractLayoutItem* plane : qAsConst(planeLayoutItems) ) {
         plane->removeFromParentLayout();
     }
     //TODO they should get a correct parent, but for now it works
-    Q_FOREACH( AbstractLayoutItem* plane, planeLayoutItems ) {
+    for ( AbstractLayoutItem* plane : qAsConst(planeLayoutItems) ) {
         if ( dynamic_cast< AutoSpacerLayoutItem* >( plane ) )
             delete plane;
     }
@@ -706,7 +699,8 @@ void Chart::Private::slotLayoutPlanes()
                 for ( LayoutGraphNode *curColComponent = curRowComponent; curColComponent; curColComponent = curColComponent->leftSuccesor )
                 {
                     Q_ASSERT( curColComponent->diagramPlane->diagrams().size() == 1 );
-                    Q_FOREACH( AbstractDiagram* diagram, curColComponent->diagramPlane->diagrams() )
+                    const auto diags{curColComponent->diagramPlane->diagrams()};
+                    for ( AbstractDiagram* diagram :  diags )
                     {
                         const int planeRowOffset = 1;//curColComponent->topAxesLayout ? 1 : 0;
                         const int planeColOffset = 1;//curColComponent->leftAxesLayout ? 1 : 0;
@@ -729,8 +723,8 @@ void Chart::Private::slotLayoutPlanes()
                                 curColComponent->sharedSuccesor->diagramPlane->setParentLayout( gridPlaneLayout );
                                 planeLayoutItems << curColComponent->sharedSuccesor->diagramPlane;
                             }
-                            Q_FOREACH( CartesianAxis* axis, cartDiag->axes() )
-                            {
+                            const auto axes = cartDiag->axes();
+                            for ( CartesianAxis* axis : axes ) {
                                 if ( axis->isAbscissa() )
                                 {
                                     if ( curColComponent->bottomSuccesor )
@@ -840,7 +834,7 @@ void Chart::Private::slotLayoutPlanes()
          * gets their own. See buildPlaneLayoutInfos() for more details. */
         QHash<AbstractCoordinatePlane*, PlaneInfo> planeInfos = buildPlaneLayoutInfos();
         QHash<AbstractAxis*, AxisInfo> axisInfos;
-        Q_FOREACH( AbstractCoordinatePlane* plane, coordinatePlanes ) {
+        for ( AbstractCoordinatePlane* plane : qAsConst(coordinatePlanes) ) {
             Q_ASSERT( planeInfos.contains(plane) );
             PlaneInfo& pi = planeInfos[ plane ];
             const int column = pi.horizontalOffset;
@@ -872,7 +866,9 @@ void Chart::Private::slotLayoutPlanes()
             //qDebug() << "Chart slotLayoutPlanes() calls planeLayout->addItem("<< row << column << ")";
             planeLayout->setRowStretch( row, 2 );
             planeLayout->setColumnStretch( column, 2 );
-            Q_FOREACH( AbstractDiagram* abstractDiagram, plane->diagrams() )
+
+            const auto diagrams = plane->diagrams();
+            for ( AbstractDiagram* abstractDiagram : diagrams )
             {
                 AbstractCartesianDiagram* diagram =
                     qobject_cast< AbstractCartesianDiagram* >( abstractDiagram );
@@ -923,7 +919,8 @@ void Chart::Private::slotLayoutPlanes()
                 }
 
                 //pi.leftAxesLayout->setSizeConstraint( QLayout::SetFixedSize );
-                Q_FOREACH( CartesianAxis* axis, diagram->axes() ) {
+                const CartesianAxisList axes = diagram->axes();
+                for ( CartesianAxis* axis : axes ) {
                     if ( axisInfos.contains( axis ) ) {
                         continue; // already laid out this one
                     }
@@ -1084,7 +1081,7 @@ void Chart::Private::slotResizePlanes()
         layout->activate();
     }
     // Adapt diagram drawing to the new size
-    Q_FOREACH (AbstractCoordinatePlane* plane, coordinatePlanes ) {
+    for ( AbstractCoordinatePlane* plane : qAsConst(coordinatePlanes) ) {
         plane->layoutDiagrams();
     }
 }
@@ -1092,7 +1089,7 @@ void Chart::Private::slotResizePlanes()
 void Chart::Private::updateDirtyLayouts()
 {
     if ( isPlanesLayoutDirty ) {
-        Q_FOREACH ( AbstractCoordinatePlane* p, coordinatePlanes ) {
+        for ( AbstractCoordinatePlane* p : qAsConst(coordinatePlanes) ) {
             p->setGridNeedsRecalculate();
             p->layoutPlanes();
             p->layoutDiagrams();
@@ -1129,13 +1126,13 @@ void Chart::Private::paintAll( QPainter* painter )
 
     chart->reLayoutFloatingLegends();
 
-    Q_FOREACH( AbstractLayoutItem* planeLayoutItem, planeLayoutItems ) {
+    for( AbstractLayoutItem* planeLayoutItem : qAsConst(planeLayoutItems) ) {
         planeLayoutItem->paintAll( *painter );
     }
-    Q_FOREACH( TextArea* textLayoutItem, textLayoutItems ) {
+    for( TextArea* textLayoutItem : qAsConst(textLayoutItems) ) {
         textLayoutItem->paintAll( *painter );
     }
-    Q_FOREACH( Legend *legend, legends ) {
+    for ( Legend *legend : qAsConst(legends) ) {
         const bool hidden = legend->isHidden() && legend->testAttribute( Qt::WA_WState_ExplicitShowHide );
         if ( !hidden ) {
             //qDebug() << "painting legend at " << legend->geometry();
@@ -1170,6 +1167,15 @@ Chart::Chart ( QWidget* parent )
 
 Chart::~Chart()
 {
+    // early disconnect the legend, otherwise destruction of a diagram might trigger an
+    // update of the legend properties during destruction of the chart, leading to the
+    // following assert in Qt6:
+    // qobjectdefs_impl.h:119: ASSERT failure in KChart::Chart:
+    // "Called object is not of the correct type (class destructor may have already run)"
+    for (auto legend : d->legends) {
+        disconnect(legend, nullptr, this, nullptr);
+    }
+
     delete d;
 }
 
@@ -1242,12 +1248,12 @@ void Chart::insertCoordinatePlane( int index, AbstractCoordinatePlane* plane )
         return;
     }
 
-    connect( plane, SIGNAL(destroyedCoordinatePlane(AbstractCoordinatePlane*)),
-             d,   SLOT(slotUnregisterDestroyedPlane(AbstractCoordinatePlane*)) );
-    connect( plane, SIGNAL(needUpdate()),       this,   SLOT(update()) );
-    connect( plane, SIGNAL(needRelayout()),     d,      SLOT(slotResizePlanes()) ) ;
-    connect( plane, SIGNAL(needLayoutPlanes()), d,      SLOT(slotLayoutPlanes()) ) ;
-    connect( plane, SIGNAL(propertiesChanged()),this, SIGNAL(propertiesChanged()) );
+    connect( plane, &AbstractCoordinatePlane::destroyedCoordinatePlane,
+             d,   &Private::slotUnregisterDestroyedPlane );
+    connect( plane, &AbstractCoordinatePlane::needUpdate, this, QOverload<>::of(&Chart::update) );
+    connect( plane, &AbstractCoordinatePlane::needRelayout, d, &Private::slotResizePlanes ) ;
+    connect( plane, &AbstractCoordinatePlane::needLayoutPlanes, d, &Private::slotLayoutPlanes ) ;
+    connect( plane, &AbstractCoordinatePlane::propertiesChanged, this, &Chart::propertiesChanged );
     d->coordinatePlanes.insert( index, plane );
     plane->setParent( this );
     d->slotLayoutPlanes();
@@ -1285,7 +1291,7 @@ void Chart::takeCoordinatePlane( AbstractCoordinatePlane* plane )
     d->slotLayoutPlanes();
     // Need to emit the signal: In case somebody has connected the signal
     // to her own slot for e.g. calling update() on a widget containing the chart.
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void Chart::setGlobalLeading( int left, int top, int right, int bottom )
@@ -1389,7 +1395,7 @@ void Chart::resizeEvent ( QResizeEvent* event )
 
 void Chart::reLayoutFloatingLegends()
 {
-    Q_FOREACH( Legend *legend, d->legends ) {
+    for( Legend *legend : qAsConst(d->legends) ) {
         const bool hidden = legend->isHidden() && legend->testAttribute( Qt::WA_WState_ExplicitShowHide );
         if ( legend->position().isFloating() && !hidden ) {
             // resize the legend
@@ -1423,7 +1429,7 @@ void Chart::paintEvent( QPaintEvent* )
 {
     QPainter painter( this );
     d->paintAll( &painter );
-    emit finishedDrawing();
+    Q_EMIT finishedDrawing();
 }
 
 void Chart::addHeaderFooter( HeaderFooter* hf )
@@ -1439,10 +1445,10 @@ void Chart::addHeaderFooter( HeaderFooter* hf )
 
     d->headerFooters.append( hf );
     d->textLayoutItems.append( hf );
-    connect( hf, SIGNAL(destroyedHeaderFooter(HeaderFooter*)),
-             d, SLOT(slotUnregisterDestroyedHeaderFooter(HeaderFooter*)) );
-    connect( hf, SIGNAL(positionChanged(HeaderFooter*)),
-             d, SLOT(slotHeaderFooterPositionChanged(HeaderFooter*)) );
+    connect( hf, &HeaderFooter::destroyedHeaderFooter,
+             d, &Private::slotUnregisterDestroyedHeaderFooter );
+    connect( hf, &HeaderFooter::positionChanged,
+             d, &Private::slotHeaderFooterPositionChanged );
 
     // set the text attributes (why?)
 
@@ -1489,8 +1495,8 @@ void Chart::takeHeaderFooter( HeaderFooter* headerFooter )
     if ( idx == -1 ) {
         return;
     }
-    disconnect( headerFooter, SIGNAL(destroyedHeaderFooter(HeaderFooter*)),
-                d, SLOT(slotUnregisterDestroyedHeaderFooter(HeaderFooter*)) );
+    disconnect( headerFooter, &HeaderFooter::destroyedHeaderFooter,
+                d, &Private::slotUnregisterDestroyedHeaderFooter );
 
     d->headerFooters.takeAt( idx );
     headerFooter->removeFromParentLayout();
@@ -1532,7 +1538,7 @@ void Chart::addLegend( Legend* legend )
 {
     legend->show();
     addLegendInternal( legend, true );
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void Chart::addLegendInternal( Legend* legend, bool setMeasures )
@@ -1621,11 +1627,11 @@ void Chart::addLegendInternal( Legend* legend, bool setMeasures )
         sameAlignmentLayout->addItem( new MyWidgetItem( legend, legend->alignment() ) );
     }
 
-    connect( legend, SIGNAL(destroyedLegend(Legend*)),
-             d, SLOT(slotUnregisterDestroyedLegend(Legend*)) );
-    connect( legend, SIGNAL(positionChanged(AbstractAreaWidget*)),
-             d, SLOT(slotLegendPositionChanged(AbstractAreaWidget*)) );
-    connect( legend, SIGNAL(propertiesChanged()), this, SIGNAL(propertiesChanged()) );
+    connect( legend, &Legend::destroyedLegend,
+             d, &Private::slotUnregisterDestroyedLegend );
+    connect( legend, &Legend::positionChanged,
+             d, &Private::slotLegendPositionChanged );
+    connect( legend, &Legend::propertiesChanged, this, &Chart::propertiesChanged );
 
     d->slotResizePlanes();
 }
@@ -1661,7 +1667,7 @@ void Chart::takeLegend( Legend* legend )
     legend->setParent( nullptr );
 
     d->slotResizePlanes();
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 Legend* Chart::legend()
@@ -1678,7 +1684,7 @@ void Chart::mousePressEvent( QMouseEvent* event )
 {
     const QPoint pos = mapFromGlobal( event->globalPos() );
 
-    Q_FOREACH( AbstractCoordinatePlane* plane, d->coordinatePlanes ) {
+    for( AbstractCoordinatePlane* plane : qAsConst(d->coordinatePlanes) ) {
         if ( plane->geometry().contains( event->pos() ) && plane->diagrams().size() > 0 ) {
             QMouseEvent ev( QEvent::MouseButtonPress, pos, event->globalPos(),
                             event->button(), event->buttons(), event->modifiers() );
@@ -1692,7 +1698,7 @@ void Chart::mouseDoubleClickEvent( QMouseEvent* event )
 {
     const QPoint pos = mapFromGlobal( event->globalPos() );
 
-    Q_FOREACH( AbstractCoordinatePlane* plane, d->coordinatePlanes ) {
+    for( AbstractCoordinatePlane* plane : qAsConst(d->coordinatePlanes) ) {
         if ( plane->geometry().contains( event->pos() ) && plane->diagrams().size() > 0 ) {
             QMouseEvent ev( QEvent::MouseButtonPress, pos, event->globalPos(),
                             event->button(), event->buttons(), event->modifiers() );
@@ -1703,9 +1709,9 @@ void Chart::mouseDoubleClickEvent( QMouseEvent* event )
 
 void Chart::mouseMoveEvent( QMouseEvent* event )
 {
-    QSet< AbstractCoordinatePlane* > eventReceivers = QSet< AbstractCoordinatePlane* >::fromList( d->mouseClickedPlanes );
+    auto eventReceivers = QSet<AbstractCoordinatePlane*>(d->mouseClickedPlanes.cbegin(), d->mouseClickedPlanes.cend());
 
-    Q_FOREACH( AbstractCoordinatePlane* plane, d->coordinatePlanes ) {
+    for( AbstractCoordinatePlane* plane : qAsConst(d->coordinatePlanes) ) {
         if ( plane->geometry().contains( event->pos() ) && plane->diagrams().size() > 0 ) {
             eventReceivers.insert( plane );
         }
@@ -1713,7 +1719,7 @@ void Chart::mouseMoveEvent( QMouseEvent* event )
 
     const QPoint pos = mapFromGlobal( event->globalPos() );
 
-    Q_FOREACH( AbstractCoordinatePlane* plane, eventReceivers ) {
+    for( AbstractCoordinatePlane* plane : qAsConst(eventReceivers) ) {
         QMouseEvent ev( QEvent::MouseMove, pos, event->globalPos(),
                          event->button(), event->buttons(), event->modifiers() );
         plane->mouseMoveEvent( &ev );
@@ -1722,9 +1728,9 @@ void Chart::mouseMoveEvent( QMouseEvent* event )
 
 void Chart::mouseReleaseEvent( QMouseEvent* event )
 {
-    QSet< AbstractCoordinatePlane* > eventReceivers = QSet< AbstractCoordinatePlane* >::fromList( d->mouseClickedPlanes );
+    auto eventReceivers = QSet<AbstractCoordinatePlane*>(d->mouseClickedPlanes.cbegin(), d->mouseClickedPlanes.cend());
 
-    Q_FOREACH( AbstractCoordinatePlane* plane, d->coordinatePlanes ) {
+    for ( AbstractCoordinatePlane* plane :  qAsConst(d->coordinatePlanes) ) {
         if ( plane->geometry().contains( event->pos() ) && plane->diagrams().size() > 0 ) {
             eventReceivers.insert( plane );
         }
@@ -1732,7 +1738,7 @@ void Chart::mouseReleaseEvent( QMouseEvent* event )
 
     const QPoint pos = mapFromGlobal( event->globalPos() );
 
-    Q_FOREACH( AbstractCoordinatePlane* plane, eventReceivers ) {
+    for( AbstractCoordinatePlane* plane : qAsConst(eventReceivers) ) {
         QMouseEvent ev( QEvent::MouseButtonRelease, pos, event->globalPos(),
                          event->button(), event->buttons(), event->modifiers() );
         plane->mouseReleaseEvent( &ev );
@@ -1745,7 +1751,7 @@ bool Chart::event( QEvent* event )
 {
     if ( event->type() == QEvent::ToolTip ) {
         const QHelpEvent* const helpEvent = static_cast< QHelpEvent* >( event );
-        Q_FOREACH( const AbstractCoordinatePlane* const plane, d->coordinatePlanes ) {
+        for( const AbstractCoordinatePlane* const plane : qAsConst(d->coordinatePlanes) ) {
             // iterate diagrams in reverse, so that the top-most painted diagram is
             // queried first for a tooltip before the diagrams behind it
             const ConstAbstractDiagramList& diagrams = plane->diagrams();
