@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartDatasetSelector.h"
@@ -56,7 +45,7 @@ void DatasetSelectorWidget::updateState( bool state )
     {
         calculateMapping();
     } else {
-        emit mappingDisabled();
+        Q_EMIT mappingDisabled();
     }
 }
 
@@ -94,7 +83,7 @@ void DatasetSelectorWidget::resetDisplayValues()
     mUi->sbColumnCount->setMaximum( mSourceColumnCount );
     mUi->sbColumnCount->setValue( mSourceColumnCount );
     mUi->groupBox->setChecked( false );
-    emit mappingDisabled();
+    Q_EMIT mappingDisabled();
 }
 
 void DatasetSelectorWidget::calculateMapping()
@@ -102,13 +91,13 @@ void DatasetSelectorWidget::calculateMapping()
     if ( mSourceColumnCount < 2 && mSourceRowCount < 2 )
     {
         mUi->groupBox->setEnabled( false );
-        emit mappingDisabled();
+        Q_EMIT mappingDisabled();
     } else {
         mUi->groupBox->setEnabled( true );
 
         if ( ! mUi->groupBox->isChecked() )
         {
-            emit mappingDisabled();
+            Q_EMIT mappingDisabled();
             return;
         }
 
@@ -158,7 +147,7 @@ void DatasetSelectorWidget::calculateMapping()
         }
 
         // and tell the world:
-        emit configureDatasetProxyModel( rowConfig, columnConfig );
+        Q_EMIT configureDatasetProxyModel( rowConfig, columnConfig );
     }
 }
 
