@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <KChartDiagramObserver.h>
@@ -97,16 +86,16 @@ void DiagramObserver::init()
 void DiagramObserver::slotDestroyed(QObject*)
 {
     //qDebug() << this << "emits signal\n"
-    //        "    emit diagramDestroyed(" <<  m_diagram << ")";
+    //        "    Q_EMIT diagramDestroyed(" <<  m_diagram << ")";
     AbstractDiagram* diag = m_diagram;
     disconnect( m_diagram, nullptr, this, nullptr);
     m_diagram = nullptr;
-    emit diagramDestroyed( diag );
+    Q_EMIT diagramDestroyed( diag );
 }
 
 void DiagramObserver::slotAboutToBeDestroyed()
 {
-    emit diagramAboutToBeDestroyed( m_diagram );
+    Q_EMIT diagramAboutToBeDestroyed( m_diagram );
 }
 
 void DiagramObserver::slotModelsChanged()
@@ -119,7 +108,7 @@ void DiagramObserver::slotModelsChanged()
 void DiagramObserver::slotHeaderDataChanged(Qt::Orientation,int,int)
 {
     //qDebug() << "DiagramObserver::slotHeaderDataChanged()";
-    emit diagramDataChanged( m_diagram );
+    Q_EMIT diagramDataChanged( m_diagram );
 }
 
 void DiagramObserver::slotDataChanged(QModelIndex,QModelIndex)
@@ -130,13 +119,13 @@ void DiagramObserver::slotDataChanged(QModelIndex,QModelIndex)
 void DiagramObserver::slotDataChanged()
 {
     //qDebug() << "DiagramObserver::slotDataChanged()";
-    emit diagramDataChanged( m_diagram );
+    Q_EMIT diagramDataChanged( m_diagram );
 }
 
 void DiagramObserver::slotDataHidden()
 {
     //qDebug() << "DiagramObserver::slotDataHidden()";
-    emit diagramDataHidden( m_diagram );
+    Q_EMIT diagramDataHidden( m_diagram );
 }
 
 void DiagramObserver::slotAttributesChanged(QModelIndex,QModelIndex)
@@ -147,6 +136,6 @@ void DiagramObserver::slotAttributesChanged(QModelIndex,QModelIndex)
 void DiagramObserver::slotAttributesChanged()
 {
     //qDebug() << "DiagramObserver::slotAttributesChanged()";
-    emit diagramAttributesChanged( m_diagram );
+    Q_EMIT diagramAttributesChanged( m_diagram );
 }
 
