@@ -1,20 +1,9 @@
-/**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+/*
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KCHARTHEADERFOOTER_H
@@ -38,9 +27,12 @@ class KCHART_EXPORT HeaderFooter : public TextArea
     KCHART_DECLARE_PRIVATE_DERIVED_PARENT( HeaderFooter, Chart* )
 
 public:
-    HeaderFooter( Chart* parent = 0 );
-    virtual ~HeaderFooter();
+    HeaderFooter( Chart* parent = nullptr );
+    ~HeaderFooter() override;
 
+    /**
+      * Creates an exact copy of this header/footer.
+      */
     virtual HeaderFooter * clone() const;
 
     bool compare( const HeaderFooter& other ) const;
@@ -57,8 +49,8 @@ public:
     void setParent( QObject* parent );
 
 Q_SIGNALS:
-    void destroyedHeaderFooter( HeaderFooter* );
-    void positionChanged( HeaderFooter* );
+    void destroyedHeaderFooter( KChart::HeaderFooter* );
+    void positionChanged( KChart::HeaderFooter* );
 
 }; // End of class HeaderFooter
 
