@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartLayoutItems.h"
@@ -33,7 +22,6 @@
 #include <QTextBlockFormat>
 #include <QTextDocumentFragment>
 #include <QAbstractTextDocumentLayout>
-#include <QLayout>
 #include <QPainter>
 #include <QDebug>
 #include <QCoreApplication>
@@ -169,7 +157,7 @@ void KChart::TextBubbleLayoutItem::paint( QPainter* painter )
     const QBrush oldBrush = painter->brush();
     painter->setPen( Qt::black );
     painter->setBrush( QColor( 255, 255, 220 ) );
-    painter->drawRoundRect( geometry(), 10 );
+    painter->drawRoundedRect( geometry(), 10, Qt::RelativeSize );
     painter->setPen( oldPen );
     painter->setBrush( oldBrush );
     m_text->paint( painter );
@@ -980,7 +968,7 @@ void KChart::AutoSpacerLayoutItem::paint( QPainter* painter )
         const QPoint oldBrushOrigin( painter->brushOrigin() );
         const QBrush oldBrush( painter->brush() );
         const QPen   oldPen( painter->pen() );
-        const QPointF newTopLeft( painter->deviceMatrix().map( p1 ) );
+        const QPointF newTopLeft( painter->deviceTransform().map( p1 ) );
         painter->setBrushOrigin( newTopLeft );
         painter->setBrush( mCommonBrush );
         painter->setPen( Qt::NoPen );
