@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartLegend.h"
@@ -67,7 +56,7 @@ Legend::Private::Private() :
 
 Legend::Private::~Private()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 
@@ -91,7 +80,7 @@ Legend::Legend( AbstractDiagram* diagram, QWidget* parent ) :
 
 Legend::~Legend()
 {
-    emit destroyedLegend( this );
+    Q_EMIT destroyedLegend( this );
 }
 
 void Legend::init()
@@ -143,7 +132,7 @@ QSize Legend::sizeHint() const
 #ifdef DEBUG_LEGEND_PAINT
     qDebug()  << "Legend::sizeHint() started";
 #endif
-    Q_FOREACH( AbstractLayoutItem* paintItem, d->paintItems ) {
+    for ( AbstractLayoutItem* paintItem : d->paintItems ) {
         paintItem->sizeHint();
     }
     return AbstractAreaWidget::sizeHint();
@@ -246,7 +235,7 @@ void Legend::paint( QPainter* painter )
 
     activateTheLayout();
 
-    Q_FOREACH( AbstractLayoutItem* paintItem, d->paintItems ) {
+    for ( AbstractLayoutItem* paintItem : qAsConst(d->paintItems) ) {
         paintItem->paint( painter );
     }
 
@@ -283,7 +272,7 @@ void Legend::paint( QPainter *painter, const QRect& rect )
 uint Legend::datasetCount() const
 {
     int modelLabelsCount = 0;
-    Q_FOREACH ( DiagramObserver* observer, d->observers ) {
+    for ( DiagramObserver* observer : d->observers ) {
         AbstractDiagram* diagram = observer->diagram();
         Q_ASSERT( diagram->datasetLabels().count() == diagram->datasetBrushes().count() );
         modelLabelsCount += diagram->datasetLabels().count();
@@ -345,13 +334,13 @@ void Legend::addDiagram( AbstractDiagram* newDiagram )
         } else {
             d->observers.append( observer );
         }
-        connect( observer, SIGNAL(diagramAboutToBeDestroyed(AbstractDiagram*)),
-                 SLOT(resetDiagram(AbstractDiagram*)));
-        connect( observer, SIGNAL(diagramDataChanged(AbstractDiagram*)),
+        connect( observer, SIGNAL(diagramAboutToBeDestroyed(KChart::AbstractDiagram*)),
+                 SLOT(resetDiagram(KChart::AbstractDiagram*)));
+        connect( observer, SIGNAL(diagramDataChanged(KChart::AbstractDiagram*)),
                  SLOT(setNeedRebuild()));
-        connect( observer, SIGNAL(diagramDataHidden(AbstractDiagram*)),
+        connect( observer, SIGNAL(diagramDataHidden(KChart::AbstractDiagram*)),
                  SLOT(setNeedRebuild()));
-        connect( observer, SIGNAL(diagramAttributesChanged(AbstractDiagram*)),
+        connect( observer, SIGNAL(diagramAttributesChanged(KChart::AbstractDiagram*)),
                  SLOT(setNeedRebuild()));
         setNeedRebuild();
     }
@@ -469,8 +458,8 @@ void Legend::setPosition( Position position )
 
 void Legend::emitPositionChanged()
 {
-    emit positionChanged( this );
-    emit propertiesChanged();
+    Q_EMIT positionChanged( this );
+    Q_EMIT propertiesChanged();
 }
 
 
@@ -1069,7 +1058,7 @@ void Legend::buildLegend()
 
     updateToplevelLayout( this );
 
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 #ifdef DEBUG_LEGEND_PAINT
     qDebug() << "leaving Legend::buildLegend()";
 #endif
@@ -1212,7 +1201,7 @@ int Legend::heightForWidth( int width ) const
 
     int currentLineWidth = 0;
     int currentLineHeight = 0;
-    Q_FOREACH( const HDatasetItem &hdsItem, d->hLayoutDatasets ) {
+    for ( const HDatasetItem &hdsItem : d->hLayoutDatasets ) {
         const int payloadWidth = hdsItem.markerLine->sizeHint().width() +
                                  hdsItem.label->sizeHint().width();
         if ( !currentLineWidth ) {
