@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KCHARTLEGEND_P_H
@@ -77,7 +66,7 @@ class Q_DECL_HIDDEN Legend::Private : public AbstractAreaWidget::Private
     friend class Legend;
 public:
     Private();
-    ~Private();
+    ~Private() override;
 
     DiagramObserver* findObserverForDiagram( AbstractDiagram* diagram )
     {
@@ -86,7 +75,7 @@ public:
             if ( obs->diagram() == diagram )
                 return obs;
         }
-        return 0;
+        return nullptr;
     }
 
     void fetchPaintOptions( Legend *q );
