@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartRelativePosition.h"
@@ -48,7 +37,7 @@ private:
 
 
 RelativePosition::Private::Private()
-    : area( 0 ),
+    : area( nullptr ),
       alignment( Qt::AlignCenter ),
       rotation( 0 )
 {
@@ -98,7 +87,7 @@ QObject * RelativePosition::referenceArea() const {
 void RelativePosition::setReferencePoints( const PositionPoints& points ) {
     d->points = points;
     if ( !points.isNull() )
-        setReferenceArea( 0 );
+        setReferenceArea( nullptr );
 }
 const PositionPoints RelativePosition::referencePoints() const{
     return d->points;
@@ -151,7 +140,7 @@ qreal RelativePosition::rotation() const {
 
 const QPointF RelativePosition::referencePoint( qreal* polarDegrees ) const
 {
-    bool useRect = ( d->area != 0 );
+    bool useRect = ( d->area != nullptr );
     QRect rect;
     if ( useRect ) {
         if ( const QWidget* widget = qobject_cast< const QWidget* >( d->area ) ) {
