@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartTextArea.h"
@@ -33,13 +22,13 @@ using namespace KChart;
 TextArea::Private::Private() :
     AbstractAreaBase::Private()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 
 TextArea::Private::~Private()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 
@@ -48,18 +37,18 @@ TextArea::TextArea()
     , KChart::AbstractAreaBase()
     , KChart::TextLayoutItem()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 TextArea::~TextArea()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 
 void TextArea::init()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 void TextArea::paintIntoRect( QPainter& painter, const QRect& rect )
@@ -103,6 +92,6 @@ QRect TextArea::areaGeometry() const
 
 void TextArea::positionHasChanged()
 {
-    emit positionChanged( this );
+    Q_EMIT positionChanged( this );
 }
 
