@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KCHART_TEXT_AREA_H
@@ -50,7 +39,7 @@ class KCHART_EXPORT TextArea : public QObject, public AbstractAreaBase, public T
 
 
 public:
-    virtual ~TextArea() ;
+    ~TextArea()  override;
 
 //    virtual TextArea * clone() const = 0;
     /**
@@ -65,15 +54,15 @@ public:
       * Call paintAll, if you want the background and the frame to be drawn
       * before the normal paint() is invoked automatically.
       */
-    void paintAll( QPainter& painter ) Q_DECL_OVERRIDE;
+    void paintAll( QPainter& painter ) override;
 
 protected:
     TextArea();
-    QRect areaGeometry() const Q_DECL_OVERRIDE;
-    void positionHasChanged() Q_DECL_OVERRIDE;
+    QRect areaGeometry() const override;
+    void positionHasChanged() override;
 
 Q_SIGNALS:
-    void positionChanged( TextArea * );
+    void positionChanged( KChart::TextArea * );
 
     //KCHART_DECLARE_PRIVATE_DERIVED(TextArea)
 }; // End of class TextArea
