@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartAbstractPieDiagram.h"
@@ -116,19 +105,19 @@ bool AbstractPieDiagram::autoRotateLabels() const
 void AbstractPieDiagram::setPieAttributes( const PieAttributes & attrs )
 {
     d->attributesModel->setModelData( QVariant::fromValue( attrs ), PieAttributesRole );
-    emit layoutChanged( this );
+    Q_EMIT layoutChanged( this );
 }
 
 void AbstractPieDiagram::setPieAttributes( int column, const PieAttributes & attrs )
 {
     d->setDatasetAttrs( column, QVariant::fromValue( attrs ), PieAttributesRole );
-    emit layoutChanged( this );
+    Q_EMIT layoutChanged( this );
 }
 
 void AbstractPieDiagram::setPieAttributes( const QModelIndex & index, const PieAttributes & attrs )
 {
 	d->attributesModel->setData( index, QVariant::fromValue( attrs), PieAttributesRole );
-	emit layoutChanged( this );
+    Q_EMIT layoutChanged( this );
 }
 
 PieAttributes AbstractPieDiagram::pieAttributes() const
@@ -155,19 +144,19 @@ PieAttributes AbstractPieDiagram::pieAttributes( const QModelIndex & index ) con
 void AbstractPieDiagram::setThreeDPieAttributes( const ThreeDPieAttributes & tda )
 {
     d->attributesModel->setModelData( QVariant::fromValue( tda ), ThreeDPieAttributesRole );
-    emit layoutChanged( this );
+    Q_EMIT layoutChanged( this );
 }
 
 void AbstractPieDiagram::setThreeDPieAttributes( int column, const ThreeDPieAttributes & tda )
 {
     d->setDatasetAttrs( column, QVariant::fromValue( tda ), ThreeDPieAttributesRole );
-    emit layoutChanged( this );
+    Q_EMIT layoutChanged( this );
 }
 
 void AbstractPieDiagram::setThreeDPieAttributes( const QModelIndex & index, const ThreeDPieAttributes & tda )
 {
     model()->setData( index, QVariant::fromValue( tda ), ThreeDPieAttributesRole );
-    emit layoutChanged( this );
+    Q_EMIT layoutChanged( this );
 }
 
 ThreeDPieAttributes AbstractPieDiagram::threeDPieAttributes() const
