@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartPieDiagram.h"
@@ -58,9 +47,6 @@ void PieDiagram::init()
 {
 }
 
-/**
-  * Creates an exact copy of this diagram.
-  */
 PieDiagram * PieDiagram::clone() const
 {
     return new PieDiagram( new Private( *d ) );
@@ -280,7 +266,7 @@ void PieDiagram::placeLabels( PaintContext* paintContext )
             if ( maxOverhang > 0.0 ) {
                 // subtract 2x as much because every side only gets half of the total diameter reduction
                 // and we have to make up for the overhang on one particular side.
-                d->size -= qMin( d->size, maxOverhang * 2.0 );
+                d->size -= qMin<qreal>( d->size, maxOverhang * 2.0 );
                 tryAgain = true;
             }
         }
@@ -498,7 +484,7 @@ void PieDiagram::paintInternal( PaintContext* paintContext )
     const QPointF center = paintContext->rectangle().center();
     const PainterSaver painterSaver( paintContext->painter() );
     paintContext->painter()->setBrush( Qt::NoBrush );
-    Q_FOREACH( const LabelPaintInfo &pi, d->labelPaintCache.paintReplay ) {
+    for( const LabelPaintInfo &pi : qAsConst(d->labelPaintCache.paintReplay) ) {
         // we expect the PainterPath to be a rectangle
         if ( pi.labelArea.elementCount() != 5 ) {
             continue;
@@ -541,14 +527,6 @@ QRectF PieDiagram::explodedDrawPosition( const QRectF& drawPosition, uint slice
     return adjustedDrawPosition;
 }
 
-/**
-  Internal method that draws one of the slices in a pie chart.
-
-  \param painter the QPainter to draw in
-  \param dataset the dataset to draw the pie for
-  \param slice the slice to draw
-  \param threeDPieHeight the height of the three dimensional effect
-  */
 void PieDiagram::drawSlice( QPainter* painter, const QRectF& drawPosition, uint slice)
 {
     // Is there anything to draw at all?
@@ -560,13 +538,6 @@ void PieDiagram::drawSlice( QPainter* painter, const QRectF& drawPosition, uint
     drawSliceSurface( painter, adjustedDrawPosition, slice );
 }
 
-/**
-  Internal method that draws the surface of one of the slices in a pie chart.
-
-  \param painter the QPainter to draw in
-  \param dataset the dataset to draw the slice for
-  \param slice the slice to draw
-  */
 void PieDiagram::drawSliceSurface( QPainter* painter, const QRectF& drawPosition, uint slice )
 {
     // Is there anything to draw at all?
@@ -682,7 +653,7 @@ void PieDiagram::addSliceLabel( LabelPaintCache* lpc, const QRectF& drawPosition
         }
     }
 
-    d->addLabel( lpc, index, 0, points, Position::Center, Position::Center,
+    d->addLabel( lpc, index, nullptr, points, Position::Center, Position::Center,
                  angleLen * sum / 360, favoriteTextAngle );
 }
 
@@ -717,13 +688,6 @@ static bool doArcsOverlap( qreal a1Start, qreal a1End, qreal a2Start, qreal a2En
     }
 }
 
-/**
-  Internal method that draws the shadow creating the 3D effect of a pie
-
-  \param painter the QPainter to draw in
-  \param drawPosition the position to draw at
-  \param slice the slice to draw the shadow for
-  */
 void PieDiagram::draw3DEffect( QPainter* painter, const QRectF& drawPosition, uint slice )
 {
     const QModelIndex index( model()->index( 0, slice, rootIndex() ) ); // checked
@@ -778,15 +742,6 @@ void PieDiagram::draw3DEffect( QPainter* painter, const QRectF& drawPosition, ui
 }
 
 
-/**
-  Internal method that draws the cut surface of a slice (think of a real pie cut into slices)
-  in 3D mode, for surfaces that are facing the observer.
-
-  \param painter the QPainter to draw in
-  \param rect the position to draw at
-  \param threeDHeight the height of the shadow
-  \param angle the angle of the segment
-  */
 void PieDiagram::draw3dCutSurface( QPainter* painter,
         const QRectF& rect,
         qreal threeDHeight,
@@ -803,15 +758,6 @@ void PieDiagram::draw3dCutSurface( QPainter* painter,
     painter->drawPolygon( poly );
 }
 
-/**
-  Internal method that draws the outer rim of a slice when the rim is facing the observer.
-
-  \param painter the QPainter to draw in
-  \param rect the position to draw at
-  \param threeDHeight the height of the shadow
-  \param startAngle the starting angle of the segment
-  \param endAngle the ending angle of the segment
-  */
 void PieDiagram::draw3dOuterRim( QPainter* painter,
         const QRectF& rect,
         qreal threeDHeight,
@@ -862,12 +808,6 @@ void PieDiagram::draw3dOuterRim( QPainter* painter,
     painter->drawPolygon( poly );
 }
 
-/**
-  Internal method that finds the slice that is located at the position specified by \c angle.
-
-  \param angle the angle at which to search for a slice
-  \return the number of the slice found
-  */
 uint PieDiagram::findSliceAt( qreal angle, int colCount )
 {
     for ( int i = 0; i < colCount; ++i ) {
@@ -886,12 +826,6 @@ uint PieDiagram::findSliceAt( qreal angle, int colCount )
 }
 
 
-/**
-  Internal method that finds the slice that is located to the left of \c slice.
-
-  \param slice the slice to start the search from
-  \return the number of the pie to the left of \c pie
-  */
 uint PieDiagram::findLeftSlice( uint slice, int colCount )
 {
     if ( slice == 0 ) {
@@ -906,12 +840,6 @@ uint PieDiagram::findLeftSlice( uint slice, int colCount )
 }
 
 
-/**
-  Internal method that finds the slice that is located to the right of \c slice.
-
-  \param slice the slice to start the search from
-  \return the number of the slice to the right of \c slice
-  */
 uint PieDiagram::findRightSlice( uint slice, int colCount )
 {
     int rightSlice = slice + 1;
@@ -922,10 +850,6 @@ uint PieDiagram::findRightSlice( uint slice, int colCount )
 }
 
 
-/**
-  * Auxiliary method returning a point to a given boundary
-  * rectangle of the enclosed ellipse and an angle.
-  */
 QPointF PieDiagram::pointOnEllipse( const QRectF& boundingBox, qreal angle )
 {
     qreal angleRad = DEGTORAD( angle );
