@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartPolarCoordinatePlane.h"
@@ -42,17 +31,17 @@ using namespace KChart;
 PolarCoordinatePlane::PolarCoordinatePlane ( Chart* parent )
     : AbstractCoordinatePlane ( new Private(), parent )
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 PolarCoordinatePlane::~PolarCoordinatePlane()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 void PolarCoordinatePlane::init()
 {
-    // this bloc left empty intentionally
+    // this block left empty intentionally
 }
 
 void PolarCoordinatePlane::addDiagram ( AbstractDiagram* diagram )
@@ -61,8 +50,8 @@ void PolarCoordinatePlane::addDiagram ( AbstractDiagram* diagram )
                  "PolarCoordinatePlane::addDiagram", "Only polar"
                  "diagrams can be added to a polar coordinate plane!" );
     AbstractCoordinatePlane::addDiagram ( diagram );
-    connect ( diagram,  SIGNAL (layoutChanged(AbstractDiagram*)),
-              SLOT (slotLayoutChanged(AbstractDiagram*)) );
+    connect ( diagram,  SIGNAL (layoutChanged(KChart::AbstractDiagram*)),
+              SLOT (slotLayoutChanged(KChart::AbstractDiagram*)) );
 
 }
 
@@ -158,8 +147,8 @@ void PolarCoordinatePlane::layoutDiagrams()
     // FIXME distribute space according to options:
     const qreal oldStartPosition = startPosition();
     d->coordinateTransformations.clear();
-    Q_FOREACH( AbstractDiagram* diagram, diagrams() )
-        {
+    const auto ds = diagrams();
+    for ( AbstractDiagram* diagram : ds ) {
             AbstractPolarDiagram *polarDiagram = dynamic_cast<AbstractPolarDiagram*>( diagram );
             Q_ASSERT( polarDiagram );
             QPair<QPointF, QPointF> dataBoundariesPair = polarDiagram->dataBoundaries();
@@ -321,7 +310,7 @@ void KChart::PolarCoordinatePlane::setGridAttributes(
         d->gridAttributesSagittal = a;
     setHasOwnGridAttributes( circular, true );
     update();
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 void KChart::PolarCoordinatePlane::resetGridAttributes(
@@ -363,7 +352,7 @@ void KChart::PolarCoordinatePlane::setHasOwnGridAttributes(
         d->hasOwnGridAttributesCircular = on;
     else
         d->hasOwnGridAttributesSagittal = on;
-    emit propertiesChanged();
+    Q_EMIT propertiesChanged();
 }
 
 bool KChart::PolarCoordinatePlane::hasOwnGridAttributes(
