@@ -1,20 +1,9 @@
-/**
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+/*
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "ReverseMapper.h"
@@ -33,42 +22,44 @@
 using namespace KChart;
 
 ReverseMapper::ReverseMapper()
-    : m_scene( 0 )
-    , m_diagram( 0 )
+    : m_diagram( nullptr )
+    , m_scene( nullptr )
 {
 }
 
 ReverseMapper::ReverseMapper( AbstractDiagram* diagram )
-    : m_scene( 0 )
-    , m_diagram( diagram )
+    : m_diagram( diagram )
+    , m_scene( nullptr )
 {
 }
 
 ReverseMapper::~ReverseMapper()
 {
-    delete m_scene; m_scene = 0;
+    delete m_scene;
+    m_scene = nullptr;
 }
 
 void ReverseMapper::setDiagram( AbstractDiagram* diagram )
 {
-
     m_diagram = diagram;
 }
 
 void ReverseMapper::clear()
 {
-    m_itemMap.clear();
-    delete m_scene;
-    m_scene = new QGraphicsScene();
+    m_polygons.clear();
+    if (m_scene)
+        m_scene->clear();
+    m_sceneDirty = true;
 }
 
 QModelIndexList ReverseMapper::indexesIn( const QRect& rect ) const
 {
-    Q_ASSERT( m_diagram );
-    if ( m_scene && m_scene->sceneRect().intersects( rect ) ) {
-        QList<QGraphicsItem *> items = m_scene->items( rect );
+    populateScene();
+
+    if ( m_scene->sceneRect().intersects( rect ) ) {
+        const QList<QGraphicsItem *> items = m_scene->items( rect );
         QModelIndexList indexes;
-        Q_FOREACH( QGraphicsItem* item, items ) {
+        for ( QGraphicsItem* item : items ) {
             ChartGraphicsItem* i = qgraphicsitem_cast<ChartGraphicsItem*>( item );
             if ( i ) {
                 QModelIndex index ( m_diagram->model()->index( i->row(), i->column(), m_diagram->rootIndex() ) ); // checked
@@ -83,11 +74,12 @@ QModelIndexList ReverseMapper::indexesIn( const QRect& rect ) const
 
 QModelIndexList ReverseMapper::indexesAt( const QPointF& point ) const
 {
-    Q_ASSERT( m_diagram );
-    if ( m_scene && m_scene->sceneRect().contains( point ) ) {
-        QList<QGraphicsItem *> items = m_scene->items( point );
+    populateScene();
+
+    if ( m_scene->sceneRect().contains( point ) ) {
+        const QList<QGraphicsItem *> items = m_scene->items( point );
         QModelIndexList indexes;
-        Q_FOREACH( QGraphicsItem* item, items ) {
+        for ( QGraphicsItem* item : items ) {
             ChartGraphicsItem* i = qgraphicsitem_cast<ChartGraphicsItem*>( item );
             if ( i ) {
                 QModelIndex index ( m_diagram->model()->index( i->row(), i->column(), m_diagram->rootIndex() ) ); // checked
@@ -106,22 +98,12 @@ QPolygonF ReverseMapper::polygon( int row, int column ) const
     if ( !m_diagram->model()->hasIndex( row, column, m_diagram->rootIndex() ) )
         return QPolygon();
     const QModelIndex index = m_diagram->model()->index( row, column, m_diagram->rootIndex() ); // checked
-    return m_itemMap.contains( index ) ? m_itemMap[ index ]->polygon() : QPolygon();
+    return m_polygons.value(index);
 }
 
 QRectF ReverseMapper::boundingRect( int row, int column ) const
 {
-    if ( !m_diagram->model()->hasIndex( row, column, m_diagram->rootIndex() ) )
-        return QRectF();
-    const QModelIndex index = m_diagram->model()->index( row, column, m_diagram->rootIndex() ); // checked
-    return m_itemMap.contains( index ) ? m_itemMap[ index ]->polygon().boundingRect() : QRectF();
-}
-
-void ReverseMapper::addItem( ChartGraphicsItem* item )
-{
-    Q_ASSERT( m_scene );
-    m_scene->addItem( item );
-    m_itemMap.insert( m_diagram->model()->index( item->row(), item->column(), m_diagram->rootIndex() ), item ); // checked
+    return polygon(row, column).boundingRect();
 }
 
 void ReverseMapper::addRect( int row, int column, const QRectF& rect )
@@ -131,9 +113,15 @@ void ReverseMapper::addRect( int row, int column, const QRectF& rect )
 
 void ReverseMapper::addPolygon( int row, int column, const QPolygonF& polygon )
 {
-    ChartGraphicsItem* item = new ChartGraphicsItem( row, column );
-    item->setPolygon( polygon );
-    addItem( item );
+    const auto index = m_diagram->model()->index( row, column, m_diagram->rootIndex() );
+    auto &value = m_polygons[index];
+    if (value.isEmpty()) {
+        value = polygon;
+    } else {
+        value = value.united(polygon);
+    }
+
+    m_sceneDirty = true;
 }
 
 void ReverseMapper::addCircle( int row, int column, const QPointF& location, const QSizeF& diameter )
@@ -153,10 +141,9 @@ void ReverseMapper::addLine( int row, int column, const QPointF& from, const QPo
         return;
     }
     // lines do not make good polygons to click on. we calculate a 2
-    // pixel wide rectangle, where the original line is excatly
+    // pixel wide rectangle, where the original line is exactly
     // centered in.
     // make a 3 pixel wide polygon from the line:
-    static const QPointF pixel( 1.0, 1.0 );
     QPointF left, right;
     if ( from.x() < to.x() ) {
         left = from;
@@ -176,3 +163,29 @@ void ReverseMapper::addLine( int row, int column, const QPointF& from, const QPo
     const QPointF four( right + lineVectorUnit + normOfLineVectorUnit );
     addPolygon( row, column, QPolygonF() << one << two << three << four );
 }
+
+void ReverseMapper::populateScene() const
+{
+    // we populate the scene lazily...
+
+    Q_ASSERT( m_diagram );
+
+    if (!m_sceneDirty) {
+        return;
+    }
+
+    if (!m_scene) {
+        m_scene = new QGraphicsScene;
+    }
+
+    QRectF boundingRect;
+    for (auto it = m_polygons.constBegin(), end = m_polygons.constEnd(); it != end; ++it) {
+        auto* item = new ChartGraphicsItem( it.key().row(), it.key().column() );
+        item->setPolygon( it.value() );
+        m_scene->addItem( item );
+        boundingRect |= it.value().boundingRect();
+    }
+
+    m_scene->setSceneRect(boundingRect);
+    m_sceneDirty = false;
+}
