@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KD Chart library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KChartTernaryAxis.h"
@@ -76,9 +65,9 @@ void  TernaryAxis::paintCtx (PaintContext * paintContext)
     // paint the axis label (across the triangle, that one):
     QList<PrerenderedLabel*> labels;
     labels << m_label << m_fifty;
-    Q_FOREACH( PrerenderedLabel* label, labels ) {
+    for ( PrerenderedLabel* label : qAsConst(labels) ) {
         const QPixmap& pixmap = label->pixmap();
-        QPointF point = plane->translate( label->position() )
+        const QPointF point = plane->translate( label->position() )
                         - label->referencePointLocation();
         p->drawPixmap( point, pixmap );
     }
