@@ -1,26 +1,14 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KGantt library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kganttconstraintmodel.h"
 #include "kganttconstraintmodel_p.h"
 
-#include <QDebug>
 
 #include <cassert>
 #include <algorithm>
@@ -85,7 +73,7 @@ void ConstraintModel::init()
 }
 
 namespace {
-    struct compare_constraint_indexes_to : public std::unary_function<bool,Constraint> {
+    struct compare_constraint_indexes_to {
         compare_constraint_indexes_to( const Constraint& c )
             : m_c( c ) {
         }
@@ -154,7 +142,7 @@ void ConstraintModel::cleanup()
 {
 #if 0
     QSet<Constraint> orphans;
-    Q_FOREACH( const Constraint& c, d->constraints ) {
+    for ( const Constraint& c : qAsConst(d->constraints) ) {
         if ( !c.startIndex().isValid() || !c.endIndex().isValid() ) orphans.insert( c );
     }
     //qDebug() << "Constraint::cleanup() found" << orphans << "orphans";
@@ -195,7 +183,7 @@ bool ConstraintModel::hasConstraint( const Constraint& c ) const
 {
     /*
     // Because of a Qt bug we have to search like this
-    Q_FOREACH( Constraint c2, d->constraints ) {
+    for ( Constraint c2 : qAsConst(d->constraints) ) {
         if ( c==c2 ) return true;
     }
     return false;
@@ -214,7 +202,8 @@ bool ConstraintModel::hasConstraint( const Constraint& c ) const
 QDebug operator<<( QDebug dbg, const KGantt::ConstraintModel& model )
 {
     dbg << "KGantt::ConstraintModel[ " << static_cast<const QObject*>( &model ) << ": [\n";
-    Q_FOREACH( const Constraint& c, model.constraints() ) {
+    const auto constraints = model.constraints();
+    for ( const Constraint& c : constraints ) {
         dbg << "\t" << c << "\n";
     }
     dbg << "]\n";
