@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KGantt library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kganttdatetimegrid.h"
@@ -23,7 +12,7 @@
 #include "kganttabstractrowcontroller.h"
 
 #include <QApplication>
-#include <QDateTime>
+#include <QLocale>
 #include <QPainter>
 #include <QPainterPath>
 #include <QStyle>
@@ -129,7 +118,7 @@ QString DateTimeScaleFormatter::format( const QDateTime& datetime ) const
     const QString longWeekNumber = ( shortWeekNumber.length() == 1 ? QString::fromLatin1( "0" ) : QString() ) + shortWeekNumber;
     result.replace( QString::fromLatin1( "ww" ), longWeekNumber );
     result.replace( QString::fromLatin1( "w" ), shortWeekNumber );
-    result = datetime.toLocalTime().toString( result );
+    result = QLocale().toString(datetime.toLocalTime(), result);
     return result;
 }
 
@@ -875,7 +864,7 @@ void DateTimeGrid::paintUserDefinedHeader( QPainter* painter,
         const qreal nextx = d->dateTimeToChartX( next );
 
         QStyleOptionHeader opt;
-        if ( widget ) opt.init( widget );
+        if ( widget ) opt.initFrom( widget );
         else opt.palette = QApplication::palette();
         opt.rect = QRectF( x - offset+1, headerRect.top(), qMax<qreal>( 1., nextx-x-1 ), headerRect.height() ).toAlignedRect();
         opt.textAlignment = formatter->alignment();
@@ -932,13 +921,15 @@ void DateTimeGrid::Private::paintHeader( QPainter* painter,
           dt = dt.addSecs( offsetSeconds ), dt = dt.addDays( offsetDays ), dt = dt.addMonths( offsetMonths ),
           x = dateTimeToChartX( dt ) ) {
         QStyleOptionHeader opt;
-        if ( widget ) opt.init( widget );
+        if ( widget ) opt.initFrom( widget );
         else opt.palette = QApplication::palette();
         opt.rect = formatter->textRect( x, offset, dayWidth, headerRect, dt );
         opt.text = formatter->format( dt );
         opt.textAlignment = Qt::AlignCenter;
         style->drawControl(QStyle::CE_Header, &opt, painter, widget);
     }
+    delete formatter;
+    formatter = nullptr;
 }
 
 
@@ -948,10 +939,10 @@ void DateTimeGrid::paintHourScaleHeader( QPainter* painter,
 {
     class HourFormatter : public Private::DateTextFormatter {
     public:
-        virtual ~HourFormatter() {}
+        ~HourFormatter() override {}
 
         QString format( const QDateTime& dt ) override {
-            return dt.time().toString( QString::fromLatin1( "hh" ) );
+            return QLocale().toString(dt.time(), QString::fromLatin1( "hh" ) );
         }
         QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             Q_UNUSED(dt);
@@ -965,9 +956,9 @@ void DateTimeGrid::paintHourScaleHeader( QPainter* painter,
 
     class DayFormatter : public Private::DateTextFormatter {
     public:
-        virtual ~DayFormatter() {}
+        ~DayFormatter() override {}
         QString format( const QDateTime& dt ) override {
-            return dt.date().toString();
+            return QLocale().toString(dt.date());
         }
         QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             Q_UNUSED(dt);
@@ -986,10 +977,10 @@ void DateTimeGrid::paintDayScaleHeader( QPainter* painter,  const QRectF& header
 {
     class DayFormatter : public Private::DateTextFormatter {
     public:
-        virtual ~DayFormatter() {}
+        ~DayFormatter() override {}
 
         QString format( const QDateTime& dt ) override {
-            return dt.toString( QString::fromLatin1( "ddd" ) ).left( 1 );
+            return QLocale().toString(dt, QStringLiteral("ddd")).left(1);
         }
         QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             Q_UNUSED(dt);
@@ -1003,7 +994,7 @@ void DateTimeGrid::paintDayScaleHeader( QPainter* painter,  const QRectF& header
 
     class WeekFormatter : public Private::DateTextFormatter {
     public:
-        virtual ~WeekFormatter() {}
+        ~WeekFormatter() override {}
         QString format( const QDateTime& dt ) override {
             return QString::number(dt.date().weekNumber()) + QLatin1String("/") + QString::number(dt.date().year());
         }
@@ -1024,7 +1015,7 @@ void DateTimeGrid::paintWeekScaleHeader( QPainter* painter,  const QRectF& heade
 {
     class WeekFormatter : public Private::DateTextFormatter {
     public:
-        virtual ~WeekFormatter() {}
+        ~WeekFormatter() override {}
 
         QString format( const QDateTime& dt ) override {
             return QString::number( dt.date().weekNumber() );
@@ -1041,7 +1032,7 @@ void DateTimeGrid::paintWeekScaleHeader( QPainter* painter,  const QRectF& heade
 
     class MonthFormatter : public Private::DateTextFormatter {
     public:
-        virtual ~MonthFormatter() {}
+        ~MonthFormatter() override {}
 
         QString format( const QDateTime& dt ) override {
             return QLocale().monthName(dt.date().month(), QLocale::LongFormat) + QLatin1String("/") + QString::number(dt.date().year());
@@ -1061,7 +1052,7 @@ void DateTimeGrid::paintMonthScaleHeader( QPainter* painter,  const QRectF& head
 {
     class MonthFormatter : public Private::DateTextFormatter {
     public:
-        virtual ~MonthFormatter() {}
+        ~MonthFormatter() override {}
 
         QString format( const QDateTime& dt ) override {
             return QLocale().monthName(dt.date().month(), QLocale::ShortFormat) + QLatin1String("/") + QString::number(dt.date().year());
@@ -1076,7 +1067,7 @@ void DateTimeGrid::paintMonthScaleHeader( QPainter* painter,  const QRectF& head
 
     class YearFormatter : public Private::DateTextFormatter {
     public:
-        virtual ~YearFormatter() {}
+        ~YearFormatter() override {}
 
         QString format( const QDateTime& dt ) override {
             return QString::number( dt.date().year() );
