@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KGantt library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kganttgraphicsitem.h"
@@ -37,6 +26,7 @@
 #include <QAbstractProxyModel>
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsLineItem>
+#include <QApplication>
 
 #include <QDebug>
 
@@ -104,6 +94,7 @@ StyleOptionGanttItem GraphicsItem::getStyleOption() const
         //qDebug()<<"GraphicsItem::getStyleOption: Invalid index";
         return opt;
     }
+    opt.palette = QApplication::palette();
     opt.itemRect = rect();
     opt.boundingRect = boundingRect();
     QVariant tp = m_index.model()->data( m_index, TextPositionRole );
@@ -178,6 +169,11 @@ void GraphicsItem::paint( QPainter* painter, const QStyleOptionGraphicsItem* opt
         StyleOptionGanttItem opt = getStyleOption();
         *static_cast<QStyleOption*>(&opt) = *static_cast<const QStyleOption*>( option );
         //opt.fontMetrics = painter->fontMetrics();
+        if (widget) {
+            opt.palette = widget->palette();
+        } else {
+            opt.palette = QApplication::palette();
+        }
         scene()->itemDelegate()->paintGanttItem( painter, opt, index() );
     }
 }
@@ -263,16 +259,14 @@ void GraphicsItem::removeEndConstraint( ConstraintGraphicsItem* item )
 
 void GraphicsItem::updateConstraintItems()
 {
-    { // Workaround for multiple definition error with MSVC6
-    Q_FOREACH( ConstraintGraphicsItem* item, m_startConstraints ) {
+    for ( ConstraintGraphicsItem* item : qAsConst(m_startConstraints) ) {
         QPointF s = startConnector( item->constraint().relationType() );
         item->setStart( s );
-    }}
-    {// Workaround for multiple definition error with MSVC6
-    Q_FOREACH( ConstraintGraphicsItem* item, m_endConstraints ) {
+    }
+    for ( ConstraintGraphicsItem* item : qAsConst(m_endConstraints) ) {
         QPointF e = endConnector( item->constraint().relationType() );
         item->setEnd( e );
-    }}
+    }
 }
 
 void GraphicsItem::updateItem( const Span& rowGeometry, const QPersistentModelIndex& idx )
