@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KGantt library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kganttgraphicsscene.h"
@@ -79,9 +68,9 @@ GraphicsScene::Private::~Private()
 
 void GraphicsScene::Private::clearConstraintItems()
 {
-    for(ConstraintGraphicsItem *citem : constraintItems) {
+    for(ConstraintGraphicsItem *citem : qAsConst(constraintItems)) {
         // remove constraint from items first
-        for(GraphicsItem *item : items) {
+        for(GraphicsItem *item : qAsConst(items)) {
             item->removeStartConstraint(citem);
             item->removeEndConstraint(citem);
         }
@@ -175,7 +164,7 @@ ConstraintGraphicsItem* GraphicsScene::Private::findConstraintItem( const Constr
 // NOTE: we might get here after indexes are invalidated, so cannot do any controlled cleanup
 void GraphicsScene::Private::clearItems()
 {
-    for(GraphicsItem *item : items) {
+    for(GraphicsItem *item : qAsConst(items)) {
         q->removeItem(item);
         delete item;
     }
@@ -301,8 +290,8 @@ void GraphicsScene::setSelectionModel( QItemSelectionModel* smodel )
     if (smodel) {
         connect(d->selectionModel, SIGNAL(modelChanged(QAbstractItemModel*)),
                 this, SLOT(selectionModelChanged(QAbstractItemModel*)));
-        connect( smodel, SIGNAL(selectionChanged(const QItemSelection&,const QItemSelection&)),
-                 this, SLOT(slotSelectionChanged(const QItemSelection&,const QItemSelection&)) );
+        connect( smodel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+                 this, SLOT(slotSelectionChanged(QItemSelection,QItemSelection)) );
     }
 }
 
@@ -533,16 +522,10 @@ void GraphicsScene::removeItem( const QModelIndex& idx )
         d->items.erase( it );
         {
             // Remove any constraintitems attached
-#if QT_VERSION < QT_VERSION_CHECK(5, 1, 0)
-            // TODO remove when we depend on 5.14+
-            const QSet<ConstraintGraphicsItem*> clst = QSet<ConstraintGraphicsItem*>::fromList( item->startConstraints() ) +
-                                                       QSet<ConstraintGraphicsItem*>::fromList( item->endConstraints() );
-#else
             const QList<ConstraintGraphicsItem*> lst1 = item->startConstraints();
             const QList<ConstraintGraphicsItem*> lst2 = item->endConstraints();
             const QSet<ConstraintGraphicsItem*> clst = QSet<ConstraintGraphicsItem*>( lst1.begin(), lst1.end() ) +
                                                        QSet<ConstraintGraphicsItem*>( lst2.begin(), lst2.end() );
-#endif
             for ( ConstraintGraphicsItem* citem : clst ) {
                 d->deleteConstraintItem( citem );
             }
@@ -629,13 +612,15 @@ void GraphicsScene::selectionModelChanged(QAbstractItemModel *model)
 
 void GraphicsScene::slotSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
-    for (const QModelIndex &idx : deselected.indexes()) {
+    const auto desel = deselected.indexes();
+    for (const QModelIndex &idx : desel) {
         GraphicsItem *item = findItem(idx.model() == d->summaryHandlingModel ? idx : d->summaryHandlingModel->mapFromSource(idx));
         if (item) {
             item->setSelected(false);
         }
     }
-    for (const QModelIndex &idx : selected.indexes()) {
+    const auto sel = selected.indexes();
+    for (const QModelIndex &idx : sel) {
         GraphicsItem *item = findItem(idx.model() == d->summaryHandlingModel ? idx : d->summaryHandlingModel->mapFromSource(idx));
         if (item) {
             item->setSelected(true);
@@ -743,7 +728,9 @@ void GraphicsScene::print( QPrinter* printer, bool drawRowLabels, bool drawColum
     Q_UNUSED( drawColumnLabels );
 #else
     QPainter painter( printer );
-    doPrint( &painter, printer->pageRect(), sceneRect().left(), sceneRect().right(), printer, drawRowLabels, drawColumnLabels );
+    const auto resolution = printer->resolution();
+    const auto pageRect = printer->pageLayout().paintRectPixels(resolution);
+    doPrint( &painter, pageRect, sceneRect().left(), sceneRect().right(), printer, drawRowLabels, drawColumnLabels );
 #endif
 }
 
@@ -758,7 +745,9 @@ void GraphicsScene::print( QPrinter* printer, qreal start, qreal end, bool drawR
     Q_UNUSED( drawColumnLabels );
 #else
     QPainter painter( printer );
-    doPrint( &painter, printer->pageRect(), start, end, printer, drawRowLabels, drawColumnLabels );
+    const auto resolution = printer->resolution();
+    const auto pageRect = printer->pageLayout().paintRectPixels(resolution);
+    doPrint( &painter, pageRect, start, end, printer, drawRowLabels, drawColumnLabels );
 #endif
 }
 
@@ -885,7 +874,7 @@ void GraphicsScene::doPrintScene( QPrinter *printer, QPainter *painter, const QR
         } while ( ( sidx = rowController()->indexBelow( sidx ) ).isValid() );
         d->labelsWidth = textWidth;
         scnRect.setLeft( scnRect.left() - textWidth );
-        for( QGraphicsTextItem* item : textLabels ) {
+        for( QGraphicsTextItem* item : qAsConst(textLabels) ) {
             item->setPos( scnRect.left(), item->y() );
             item->show();
         }
@@ -1125,7 +1114,7 @@ public:
            m_destroyedFlag( destroyedFlag )
     {}
 
-    ~TestLineItem()
+    ~TestLineItem() override
     { *m_destroyedFlag = true; }
 
 private:
