@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KGantt library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kganttgraphicsview.h"
@@ -24,6 +13,7 @@
 #include "kganttconstraintmodel.h"
 #include "kganttdatetimetimelinedialog.h"
 
+#include <QLocale>
 #include <QMenu>
 #include <QPainter>
 #include <QPaintEvent>
@@ -34,6 +24,7 @@
 #include <QItemSelectionModel>
 #include <QGraphicsSceneMouseEvent>
 #include <QGuiApplication>
+#include <QActionGroup>
 
 #include <cassert>
 
@@ -61,7 +52,7 @@ HeaderWidget::~HeaderWidget()
 void HeaderWidget::scrollTo( int v )
 {
     m_offset = v;
-    // QWidget::scroll() wont work properly for me on Mac
+    // QWidget::scroll() won't work properly for me on Mac
     //scroll( static_cast<int>( old-v ), 0 );
     update();
 }
@@ -79,7 +70,7 @@ bool HeaderWidget::event( QEvent* event )
         if ( grid ) {
             QHelpEvent *e = static_cast<QHelpEvent*>( event );
             QDateTime dt = grid->mapFromChart( view()->mapToScene( e->x(), 0 ).x() ).toDateTime();
-            setToolTip( dt.toString() );
+            setToolTip(QLocale().toString(dt));
         }
     }
     return QWidget::event( event );
@@ -88,8 +79,8 @@ bool HeaderWidget::event( QEvent* event )
 void HeaderWidget::mousePressEvent(QMouseEvent *event)
 {
     DateTimeGrid* const grid = qobject_cast< DateTimeGrid* >( view()->grid() );
-    int mousePosX = event->pos().x() + view()->horizontalScrollBar()->value();
-    m_headerType = grid->sectionHandleAtPos( mousePosX, event->pos().y(), geometry() );
+    int mousePosX = event->x();
+    m_headerType = grid->sectionHandleAtPos( view()->mapToScene( event->x(), 0 ).x(), event->pos().y(), geometry() );
     if (m_headerType != DateTimeGrid::NoHeader) {
         bool hasCursor = testAttribute(Qt::WA_SetCursor);
         if (!hasCursor) {
@@ -106,7 +97,7 @@ void HeaderWidget::mouseReleaseEvent(QMouseEvent *event)
 {
     if ( m_headerType > 0 ) {
         DateTimeGrid* const grid = qobject_cast< DateTimeGrid* >( view()->grid() );
-        int mousePosX = event->pos().x() + view()->horizontalScrollBar()->value();
+        int mousePosX = view()->mapToScene( event->x(), 0 ).x();
         if ( grid->sectionHandleAtPos( mousePosX, event->pos().y(), geometry() ) == DateTimeGrid::NoHeader ) {
             bool hasCursor = testAttribute(Qt::WA_SetCursor);
             if (hasCursor) {
@@ -114,7 +105,7 @@ void HeaderWidget::mouseReleaseEvent(QMouseEvent *event)
             }
         }
         m_headerType = DateTimeGrid::NoHeader;
-        m_mousePosX = mousePosX;
+        m_mousePosX = event->x();
         QGuiApplication::restoreOverrideCursor();
     }
     QWidget::mouseReleaseEvent(event);
@@ -123,7 +114,8 @@ void HeaderWidget::mouseReleaseEvent(QMouseEvent *event)
 void HeaderWidget::mouseMoveEvent(QMouseEvent *event)
 {
     DateTimeGrid* const grid = qobject_cast< DateTimeGrid* >( view()->grid() );
-    int mousePosX = event->pos().x() + view()->horizontalScrollBar()->value();
+    int mousePosX = event->x();
+    qreal gridX = view()->mapToScene( event->x(), 0.0 ).x();
     switch ( m_headerType ) {
         case DateTimeGrid::UpperHeader:
         {
@@ -137,6 +129,7 @@ void HeaderWidget::mouseMoveEvent(QMouseEvent *event)
             return;
         }
         case DateTimeGrid::LowerHeader:
+        {
             if ( mousePosX > m_mousePosX )  {
                 grid->setDayWidth( qMax<qreal>( 1.0, grid->dayWidth() * 1.01 ) );
             } else {
@@ -145,9 +138,10 @@ void HeaderWidget::mouseMoveEvent(QMouseEvent *event)
             m_mousePosX = mousePosX;
             event->accept();
             return;
+        }
         default: {
             bool hasCursor = testAttribute(Qt::WA_SetCursor);
-            DateTimeGrid::HeaderType type = grid->sectionHandleAtPos( mousePosX, event->pos().y(), geometry());
+            DateTimeGrid::HeaderType type = grid->sectionHandleAtPos( gridX, event->pos().y(), geometry());
             if (type != DateTimeGrid::NoHeader) {
                 if (!hasCursor) {
                     setCursor(QCursor(Qt::SplitHCursor));
@@ -719,8 +713,12 @@ void GraphicsView::updateSceneRect()
 
     /* set scrollbar to keep the same time in view */
     range = horizontalScrollBar()->maximum()-horizontalScrollBar()->minimum();
-    if ( range>0 ) horizontalScrollBar()->setValue( qRound( hscroll*range ) );
-
+    if ( range>0 ) {
+        horizontalScrollBar()->setValue( qRound( hscroll*range ) );
+    } else {
+        // keep header in sync with scene
+        d->headerwidget.scrollTo(r.left());
+    }
     /* We have to update here to adjust for any rows with no
      * information because they are painted with a different
      * background brush
