@@ -1,20 +1,9 @@
 /*
- * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
+ * SPDX-FileCopyrightText: 2001-2015 Klaralvdalens Datakonsult AB. All rights reserved.
  *
  * This file is part of the KGantt library.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kganttsummaryhandlingproxymodel.h"
@@ -145,7 +134,7 @@ void SummaryHandlingProxyModel::sourceDataChanged( const QModelIndex& from, cons
             //qDebug() << "removing " << parentIdx << "from cache";
             d->removeFromCache( dataIdx );
             QModelIndex proxyDataIdx = mapFromSource( dataIdx );
-            emit dataChanged( proxyDataIdx, proxyDataIdx );
+            Q_EMIT dataChanged( proxyDataIdx, proxyDataIdx );
         }
     } while ( ( parentIdx=model->parent( parentIdx ) ) != QModelIndex() );
 
@@ -227,7 +216,7 @@ bool SummaryHandlingProxyModel::setData( const QModelIndex& index, const QVarian
 	      //qDebug() << "removing " << parentIdx << "from cache";
                 d->removeFromCache( parentIdx );
                 QModelIndex proxyParentIdx = mapFromSource( parentIdx );
-                emit dataChanged( proxyParentIdx, proxyParentIdx );
+                Q_EMIT dataChanged( proxyParentIdx, proxyParentIdx );
             }
         } while ( ( parentIdx=model->parent( parentIdx ) ) != QModelIndex() );
     }
