@@ -1,22 +1,9 @@
 /*
- * Copyright (C) 2018 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2018 Dag Andersen <danders@get2net.dk>
  *
  * This file is part of the KGantt library.
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- * 
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #undef QT_NO_CAST_FROM_ASCII
@@ -36,7 +23,6 @@
 #include "kgantttreeviewrowcontroller.h"
 
 #include <QListView>
-#include <QTreeView>
 
 
 using namespace KGantt;
@@ -62,7 +48,7 @@ void TestKGanttView::cleanup()
 
 void TestKGanttView::testApi()
 {
-    // this sould never change
+    // this should never change
     KGantt::GraphicsScene *scene = qobject_cast<KGantt::GraphicsScene*>(view->graphicsView()->scene());
     QVERIFY(scene);
 
